@@ -1,7 +1,7 @@
 /* acconfig.h
  * #ifdefs to be controlled by "configure"
  *
- * $Id: acconfig.h,v 1.16 2000/07/14 07:11:52 guy Exp $
+ * $Id: acconfig.h,v 1.18 2000/10/17 09:21:51 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -27,14 +27,12 @@
 
 #undef VERSION
 
+#undef HAVE_PLUGINS
+
 #undef HAVE_SA_LEN
 
 #undef DATAFILE_DIR
 
-#undef NEED_INET_ATON_H
-
-#undef NEED_INET_V6DEFS_H
-
 #undef NEED_SNPRINTF_H
 
 #undef NEED_STRERROR_H
