@@ -1,7 +1,7 @@
 /* filesystem.c
  * Filesystem utility routines
  *
- * $Id: filesystem.c,v 1.2 2000/10/11 07:35:01 guy Exp $
+ * $Id: filesystem.c,v 1.4 2001/04/02 09:53:44 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -40,7 +40,97 @@
 #endif
 
 #include "filesystem.h"
-#include "util.h"
+
+/*
+ * Given a pathname, return a pointer to the last pathname separator
+ * character in the pathname, or NULL if the pathname contains no
+ * separators.
+ */
+char *
+find_last_pathname_separator(char *path)
+{
+	char *separator;
+
+#ifdef WIN32
+	char c;
+
+	/*
+	 * We have to scan for '\' or '/'.
+	 * Get to the end of the string.
+	 */
+	separator = path + strlen(path);	/* points to ending '\0' */
+	while (separator > path) {
+		c = *--separator;
+		if (c == '\\' || c == '/')
+			return separator;	/* found it */
+	}
+
+	/*
+	 * OK, we didn't find any, so no directories - but there might
+	 * be a drive letter....
+	 */
+	return strchr(path, ':');
+#else
+	separator = strrchr(path, '/');
+#endif
+	return separator;
+}
+
+/*
+ * Given a pathname, return the last component.
+ */
+char *
+get_basename(char *path)
+{
+	char *filename;
+
+	filename = find_last_pathname_separator(path);
+	if (filename == NULL) {
+		/*
+		 * There're no directories, drive letters, etc. in the
+		 * name; the pathname *is* the file name.
+		 */
+		filename = path;
+	} else {
+		/*
+		 * Skip past the pathname or drive letter separator.
+		 */
+		filename++;
+	}
+	return filename;
+}
+
+/*
+ * Given a pathname, return a string containing everything but the
+ * last component.  NOTE: this overwrites the pathname handed into
+ * it....
+ */
+char *
+get_dirname(char *path)
+{
+	char *separator;
+
+	separator = find_last_pathname_separator(path);
+	if (separator == NULL) {
+		/*
+		 * There're no directories, drive letters, etc. in the
+		 * name; there is no directory path to return.
+		 */
+		return NULL;
+	}
+
+	/*
+	 * Get rid of the last pathname separator and the final file
+	 * name following it.
+	 */
+	*separator = '\0';
+
+	/*
+	 * "path" now contains the pathname of the directory containing
+	 * the file/directory to which it referred.
+	 */
+	return path;
+}
 
 const char*
 get_home_dir(void)
