@@ -1,7 +1,7 @@
 /* proto.c
  * Routines for protocol tree
  *
- * $Id: proto.c,v 1.21 2001/04/10 19:10:10 guy Exp $
+ * $Id: proto.c,v 1.27 2001/05/09 01:22:46 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -168,8 +168,8 @@ proto_init(const char *plugin_dir,void (register_all_protocols)(void),
 {
 	static hf_register_info hf[] = {
 		{ &hf_text_only,
-		{ "Text",	"text", FT_NONE, BASE_NONE, NULL, 0x0,
-			"" }},
+		{ "",	"", FT_NONE, BASE_NONE, NULL, 0x0,
+			NULL }},
 	};
 
 	if (gmc_hfinfo)
@@ -550,11 +550,11 @@ proto_tree_add_item(proto_tree *tree, int hfindex, tvbuff_t *tvb,
 			new_fi->length = n + 1;
 			break;
 		default:
-                        g_error("new_fi->hfinfo->type %d (%s) not handled\n",
+			g_error("new_fi->hfinfo->type %d (%s) not handled\n",
 					new_fi->hfinfo->type,
 					ftype_name(new_fi->hfinfo->type));
-                        g_assert_not_reached();
-                        break;
+			g_assert_not_reached();
+			break;
 
 	}
 	CLEANUP_POP;
@@ -1524,7 +1524,11 @@ proto_item_set_text(proto_item *pi, const char *format, ...)
 void
 proto_item_set_len(proto_item *pi, gint length)
 {
-	field_info *fi = (field_info*) (((GNode*)pi)->data);
+	field_info *fi;
+	
+	if (pi == NULL)
+		return;
+	fi = (field_info*) (((GNode*)pi)->data);
 	fi->length = length;
 }
 
@@ -1806,6 +1810,23 @@ proto_register_field_init(header_field_info *hfinfo, int parent)
 			(hfinfo->type == FT_INT32) ||
 			(hfinfo->type == FT_BOOLEAN) ));
 
+	/* Require integral types to have a number base */
+	switch (hfinfo->type) {
+
+	case FT_UINT8:
+	case FT_UINT16:
+	case FT_UINT24:
+	case FT_UINT32:
+	case FT_INT8:
+	case FT_INT16:
+	case FT_INT24:
+	case FT_INT32:
+		g_assert(hfinfo->display != BASE_NONE);
+		break;
+
+	default:
+		break;
+	}
 	/* if this is a bitfield, compure bitshift */
 	if (hfinfo->bitmask) {
 		while ((hfinfo->bitmask & (1 << hfinfo->bitshift)) == 0)
@@ -1979,11 +2000,11 @@ proto_item_fill_label(field_info *fi, gchar *label_str)
 			break;
 
 		default:
-                        g_error("hfinfo->type %d (%s) not handled\n",
+			g_error("hfinfo->type %d (%s) not handled\n",
 					hfinfo->type,
 					ftype_name(hfinfo->type));
-                        g_assert_not_reached();
-                        break;
+			g_assert_not_reached();
+			break;
 	}
 }
 
@@ -2202,7 +2223,6 @@ hfinfo_uint_vals_format(header_field_info *hfinfo)
 
 	switch(hfinfo->display) {
 		case BASE_DEC:
-		case BASE_NONE:
 		case BASE_BIN: /* I'm lazy */
 			format = "%s: %s (%u)";
 			break;
@@ -2243,7 +2263,6 @@ hfinfo_uint_format(header_field_info *hfinfo)
 	/* Pick the proper format string */
 	switch(hfinfo->display) {
 		case BASE_DEC:
-		case BASE_NONE:
 		case BASE_BIN: /* I'm lazy */
 			format = "%s: %u";
 			break;
@@ -2283,7 +2302,6 @@ hfinfo_int_vals_format(header_field_info *hfinfo)
 
 	switch(hfinfo->display) {
 		case BASE_DEC:
-		case BASE_NONE:
 		case BASE_BIN: /* I'm lazy */
 			format = "%s: %s (%d)";
 			break;
@@ -2324,7 +2342,6 @@ hfinfo_int_format(header_field_info *hfinfo)
 	/* Pick the proper format string */
 	switch(hfinfo->display) {
 		case BASE_DEC:
-		case BASE_NONE:
 		case BASE_BIN: /* I'm lazy */
 			format = "%s: %d";
 			break;
@@ -2368,11 +2385,13 @@ proto_registrar_n(void)
 char*
 proto_registrar_get_name(int n)
 {
-    header_field_info *hfinfo;
-    hfinfo = proto_registrar_get_nth(n);
-    if (hfinfo)
-        return hfinfo->name;
-    else        return NULL;
+	header_field_info *hfinfo;
+
+	hfinfo = proto_registrar_get_nth(n);
+	if (hfinfo)
+		return hfinfo->name;
+	else
+		return NULL;
 }
 
 char*
@@ -2708,6 +2727,26 @@ proto_registrar_dump(void)
 	for (i = 0; i < len ; i++) {
 		hfinfo = proto_registrar_get_nth(i);
 
+		/*
+		 * Skip fields with zero-length names or abbreviations;
+		 * the pseudo-field for "proto_tree_add_text()" is such
+		 * a field, and we don't want it in the list of filterable
+		 * fields.
+		 *
+		 *
+		 * XXX - perhaps the name and abbrev field should be null
+		 * pointers rather than null strings for that pseudo-field,
+		 * but we'd have to add checks for null pointers in some
+		 * places if we did that.
+		 *
+		 * Or perhaps protocol tree items added with
+		 * "proto_tree_add_text()" should have -1 as the field index,
+		 * with no pseudo-field being used, but that might also
+		 * require special checks for -1 to be added.
+		 */
+		if (strlen(hfinfo->name) == 0 || strlen(hfinfo->abbrev) == 0)
+			continue;
+
 		/* format for protocols */
 		if (proto_registrar_is_protocol(i)) {
 			printf("P\t%s\t%s\n", hfinfo->name, hfinfo->abbrev);
@@ -2747,7 +2786,6 @@ hfinfo_numeric_format(header_field_info *hfinfo)
 	/* Pick the proper format string */
 	switch(hfinfo->display) {
 		case BASE_DEC:
-		case BASE_NONE:
 		case BASE_OCT: /* I'm lazy */
 		case BASE_BIN: /* I'm lazy */
 			switch(hfinfo->type) {
@@ -2810,8 +2848,8 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 	switch(hfinfo->type) {
 
 		case FT_BOOLEAN:
-		        dfilter_len = abbrev_len + 6;
-		        buf = g_malloc0(dfilter_len);
+			dfilter_len = abbrev_len + 6;
+			buf = g_malloc0(dfilter_len);
 			snprintf(buf, dfilter_len, "%s == %s",
 					hfinfo->abbrev,
 					fvalue_get_integer(finfo->value) ? "1" : "0");
@@ -2826,15 +2864,15 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 		case FT_INT24:
 		case FT_INT32:
 			dfilter_len = abbrev_len + 20;
-		        buf = g_malloc0(dfilter_len);
+			buf = g_malloc0(dfilter_len);
 			format = hfinfo_numeric_format(hfinfo);
-		        snprintf(buf, dfilter_len, format, hfinfo->abbrev, fvalue_get_integer(finfo->value));
+			snprintf(buf, dfilter_len, format, hfinfo->abbrev, fvalue_get_integer(finfo->value));
 			break;
 
 		case FT_IPv4:
 			dfilter_len = abbrev_len + 4 + 15 + 1;
-		        buf = g_malloc0(dfilter_len);
-		        snprintf(buf, dfilter_len, "%s == %s", hfinfo->abbrev,
+			buf = g_malloc0(dfilter_len);
+			snprintf(buf, dfilter_len, "%s == %s", hfinfo->abbrev,
 					ipv4_addr_str(fvalue_get(finfo->value)));
 			break;
 
@@ -2881,34 +2919,30 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 #endif
 
 		case FT_STRING:
-		        dfilter_len = abbrev_len + 
+			dfilter_len = abbrev_len + 
 			  strlen(fvalue_get(finfo->value)) + 7;
 			buf = g_malloc0(dfilter_len);
 			snprintf(buf, dfilter_len, "%s == \"%s\"",
 				 hfinfo->abbrev, (char*)fvalue_get(finfo->value));
 			break;
 
-	        case FT_BYTES:
-		        dfilter_len = finfo->length*3 - 1;
-		        dfilter_len += abbrev_len + 7;
+		case FT_BYTES:
+			dfilter_len = finfo->length*3 - 1;
+			dfilter_len += abbrev_len + 7;
 			buf = g_malloc0(dfilter_len);
 			snprintf(buf, dfilter_len, "%s == %s",
 				 hfinfo->abbrev,
 				 bytes_to_str_punct(fvalue_get(finfo->value), finfo->length,':'));
-			break;                       
+			break;       
 		default:
-		    c = pd + finfo->start;
-		    buf = g_malloc0(32 + finfo->length * 3);
-		    ptr = buf;
+			c = pd + finfo->start;
+			buf = g_malloc0(32 + finfo->length * 3);
+			ptr = buf;
 
-		    sprintf(ptr, "frame[%d] == ", finfo->start);
-		    ptr = buf+strlen(buf);
+			sprintf(ptr, "frame[%d] == ", finfo->start);
+			ptr = buf+strlen(buf);
 
-		    if (finfo->length == 1) {
-			sprintf(ptr, "0x%02x", *c++);
-		    }
-		    else {
-			    for (i=0;i<finfo->length; i++) {
+			for (i=0;i<finfo->length; i++) {
 				if (i == 0 ) {
 					sprintf(ptr, "%02x", *c++);
 				}
@@ -2916,9 +2950,8 @@ proto_alloc_dfilter_string(field_info *finfo, guint8 *pd)
 					sprintf(ptr, ":%02x", *c++);
 				}
 				ptr = buf+strlen(buf);
-			    }
-		    }
-		    break;
+			}
+			break;
 	}
 
 	return buf;
