@@ -1,7 +1,7 @@
 /* find_dlg.c
  * Routines for "find frame" window
  *
- * $Id: find_dlg.c,v 1.16 2001/01/02 01:32:21 guy Exp $
+ * $Id: find_dlg.c,v 1.19 2001/02/01 20:21:21 gram Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -37,7 +37,7 @@
 #include <glib.h>
 
 #include "proto.h"
-#include "dfilter.h"
+#include "dfilter/dfilter.h"
 #include "globals.h"
 
 #include "ui_util.h"
@@ -74,6 +74,13 @@ find_frame_cb(GtkWidget *w, gpointer d)
                 *direction_hb, *forward_rb, *backward_rb,
                 *bbox, *ok_bt, *cancel_bt;
   GtkAccelGroup *accel_group;
+  /* No Apply button, but "OK" not only sets our text widget, it
+     activates it (i.e., it causes us to do the search). */
+  static construct_args_t args = {
+  	"Ethereal: Search Filter",
+  	FALSE,
+  	TRUE
+  };
 
   if (find_frame_w != NULL) {
     /* There's already a "Find Frame" dialog box; reactivate it. */
@@ -104,7 +111,7 @@ find_frame_cb(GtkWidget *w, gpointer d)
   
   filter_bt = gtk_button_new_with_label("Filter:");
   gtk_signal_connect(GTK_OBJECT(filter_bt), "clicked",
-    GTK_SIGNAL_FUNC(display_filter_construct_cb), NULL);
+    GTK_SIGNAL_FUNC(display_filter_construct_cb), &args);
   gtk_box_pack_start(GTK_BOX(filter_hb), filter_bt, FALSE, TRUE, 0);
   gtk_widget_show(filter_bt);
   
@@ -180,7 +187,7 @@ find_frame_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
 {
   GtkWidget *filter_te, *backward_rb;
   gchar *filter_text;
-  dfilter *sfcode;
+  dfilter_t *sfcode;
 
   filter_te = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(parent_w), E_FIND_FILT_KEY);
   backward_rb = (GtkWidget *) gtk_object_get_data(GTK_OBJECT(parent_w), E_FIND_BACKWARD_KEY);
@@ -190,7 +197,7 @@ find_frame_ok_cb(GtkWidget *ok_bt, gpointer parent_w)
   /*
    * Try to compile the filter.
    */
-  if (dfilter_compile(filter_text, &sfcode) != 0) {
+  if (!dfilter_compile(filter_text, &sfcode)) {
     /* The attempt failed; report an error. */
     simple_dialog(ESD_TYPE_CRIT, NULL, dfilter_error_msg);
     return;
