@@ -1,6 +1,6 @@
 /* main.c
  *
- * $Id: main.c,v 1.191 2001/04/10 12:07:39 gram Exp $
+ * $Id: main.c,v 1.198 2001/05/01 00:41:46 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@ethereal.com>
@@ -136,6 +136,7 @@
 #include "colors.h"
 #include "strutil.h"
 #include "register.h"
+#include "prefs.h"
 
 #ifdef WIN32
 #include "capture-wpcap.h"
@@ -465,7 +466,6 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 
 	set_menus_for_selected_tree_row(TRUE);
 
-	/*if (finfo->hfinfo && finfo->hfinfo->type != FT_TEXT_ONLY) {*/
 	if (finfo->hfinfo) {
 	  if (finfo->hfinfo->blurb != NULL && 
 	      finfo->hfinfo->blurb[0] != '\0') {
@@ -474,13 +474,33 @@ tree_view_select_row_cb(GtkCTree *ctree, GList *node, gint column, gpointer user
 	  } else {
 	    length = strlen(finfo->hfinfo->name);
 	  }
-	  length += strlen(finfo->hfinfo->abbrev) + 10;
-	  help_str = g_malloc(sizeof(gchar) * length);
-	  sprintf(help_str, "%s (%s)", 
-		  (has_blurb) ? finfo->hfinfo->blurb : finfo->hfinfo->name,
-		  finfo->hfinfo->abbrev);
-	  gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, help_str);
-	  g_free(help_str);
+          if (length) {
+	    length += strlen(finfo->hfinfo->abbrev) + 10;
+	    help_str = g_malloc(sizeof(gchar) * length);
+	    sprintf(help_str, "%s (%s)", 
+	       (has_blurb) ? finfo->hfinfo->blurb : finfo->hfinfo->name,
+	       finfo->hfinfo->abbrev);
+	    gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, help_str);
+	    g_free(help_str);
+          } else {
+            /*
+	     * Don't show anything if the field name is zero-length;
+	     * the pseudo-field for "proto_tree_add_text()" is such
+	     * a field, and we don't want "Text (text)" showing up
+	     * on the status line if you've selected such a field.
+	     *
+	     * XXX - perhaps the name and abbrev field should be null
+	     * pointers rather than null strings for that pseudo-field,
+	     * but we'd have to add checks for null pointers in some
+	     * places if we did that.
+	     *
+	     * Or perhaps protocol tree items added with
+	     * "proto_tree_add_text()" should have -1 as the field index,
+	     * with no pseudo-field being used, but that might also
+	     * require special checks for -1 to be added.
+	     */
+	    gtk_statusbar_push(GTK_STATUSBAR(info_bar), help_ctx, "");
+          }
 	}
 
 	packet_hex_print(GTK_TEXT(byte_view), byte_data, cfile.current_frame,
@@ -519,11 +539,11 @@ void expand_all_cb(GtkWidget *widget, gpointer data) {
 
 void resolve_name_cb(GtkWidget *widget, gpointer data) {
   if (cfile.protocol_tree) {
-    int tmp = g_resolving_actif;
-    g_resolving_actif = 1;
+    int tmp = prefs.name_resolve;
+    prefs.name_resolve = 1;
     gtk_clist_clear ( GTK_CLIST(tree_view) );
     proto_tree_draw(cfile.protocol_tree, tree_view);
-    g_resolving_actif = tmp;
+    prefs.name_resolve = tmp;
   }
 }
 
@@ -710,7 +730,7 @@ print_usage(void) {
   fprintf(stderr, "This is GNU " PACKAGE " " VERSION ", compiled %s\n",
 	  comp_info_str->str);
 #ifdef HAVE_LIBPCAP
-  fprintf(stderr, "%s [ -vh ] [ -kpQS ] [ -B <byte view height> ] [ -c count ]\n",
+  fprintf(stderr, "%s [ -vh ] [ -klpQS ] [ -B <byte view height> ] [ -c count ]\n",
 	  PACKAGE);
   fprintf(stderr, "\t[ -f <capture filter> ] [ -i interface ] [ -m <medium font> ] \n");
   fprintf(stderr, "\t[ -n ] [ -o <preference setting> ] ... [ -P <packet list height> ]\n");
@@ -735,6 +755,31 @@ show_version(void)
   printf("%s %s, %s\n", PACKAGE, VERSION, comp_info_str->str);
 }
 
+int
+get_positive_int(const char *string, const char *name)
+{
+  long number;
+  char *p;
+
+  number = strtol(string, &p, 10);
+  if (p == string || *p != '\0') {
+    fprintf(stderr, "ethereal: The specified %s \"%s\" is not a decimal number\n",
+	    name, string);
+    exit(1);
+  }
+  if (number < 0) {
+    fprintf(stderr, "ethereal: The specified %s \"%s\" is a negative number\n",
+	    name, string);
+    exit(1);
+  }
+  if (number > INT_MAX) {
+    fprintf(stderr, "ethereal: The specified %s \"%s\" is too large (greater than %d)\n",
+	    name, string, INT_MAX);
+    exit(1);
+  }
+  return number;
+}
+
 /* And now our feature presentation... [ fade to music ] */
 int
 main(int argc, char *argv[])
@@ -938,14 +983,14 @@ main(int argc, char *argv[])
 #endif
 
   /* Now get our args */
-  while ((opt = getopt(argc, argv, "B:c:f:hi:km:no:pP:Qr:R:Ss:t:T:w:W:vZ:")) != EOF) {
+  while ((opt = getopt(argc, argv, "B:c:f:hi:klm:no:pP:Qr:R:Ss:t:T:w:W:vZ:")) !=  EOF) {
     switch (opt) {
       case 'B':        /* Byte view pane height */
-        bv_size = atoi(optarg);
+        bv_size = get_positive_int(optarg, "byte view pane height");
         break;
       case 'c':        /* Capture xxx packets */
 #ifdef HAVE_LIBPCAP
-        cfile.count = atoi(optarg);
+        cfile.count = get_positive_int(optarg, "packet count");
 #else
         capture_option_specified = TRUE;
         arg_error = TRUE;
@@ -981,13 +1026,16 @@ main(int argc, char *argv[])
         arg_error = TRUE;
 #endif
         break;
+      case 'l':        /* Automatic scrolling in live capture mode */
+        prefs->capture_auto_scroll = TRUE;
+        break;
       case 'm':        /* Fixed-width font for the display */
         if (prefs->gui_font_name != NULL)
           g_free(prefs->gui_font_name);
 	prefs->gui_font_name = g_strdup(optarg);
 	break;
       case 'n':        /* No name resolution */
-	g_resolving_actif = 0;
+	prefs->name_resolve = 0;
 	break;
       case 'o':        /* Override preference from command line */
         switch (prefs_set_pref(optarg)) {
@@ -1006,14 +1054,14 @@ main(int argc, char *argv[])
         break;
       case 'p':        /* Don't capture in promiscuous mode */
 #ifdef HAVE_LIBPCAP
-	promisc_mode = 0;
+	prefs->capture_prom_mode = 0;
 #else
         capture_option_specified = TRUE;
         arg_error = TRUE;
 #endif
 	break;
       case 'P':        /* Packet list pane height */
-        pl_size = atoi(optarg);
+        pl_size = get_positive_int(optarg, "packet list pane height");
         break;
       case 'Q':        /* Quit after capture (just capture to file) */
 #ifdef HAVE_LIBPCAP
@@ -1035,7 +1083,7 @@ main(int argc, char *argv[])
         break;
       case 's':        /* Set the snapshot (capture) length */
 #ifdef HAVE_LIBPCAP
-        cfile.snap = atoi(optarg);
+        cfile.snap = get_positive_int(optarg, "snapshot length");
 #else
         capture_option_specified = TRUE;
         arg_error = TRUE;
@@ -1043,7 +1091,7 @@ main(int argc, char *argv[])
         break;
       case 'S':        /* "Sync" mode: used for following file ala tail -f */
 #ifdef HAVE_LIBPCAP
-        sync_mode = TRUE;
+        prefs->capture_real_time = TRUE;
 #else
         capture_option_specified = TRUE;
         arg_error = TRUE;
@@ -1067,7 +1115,7 @@ main(int argc, char *argv[])
         }
         break;
       case 'T':        /* Tree view pane height */
-        tv_size = atoi(optarg);
+        tv_size = get_positive_int(optarg, "tree view pane height");
         break;
       case 'v':        /* Show version and exit */
         show_version();
@@ -1501,7 +1549,7 @@ boldify(const char *font_name)
 {
 	char *bold_font_name;
 	gchar **xlfd_tokens;
-	int i;
+	unsigned int i;
 
 	/* Is this an XLFD font?  If it begins with "-", yes, otherwise no. */
 	if (font_name[0] == '-') {
