@@ -1,7 +1,7 @@
 /* gtkpacket.h
  * Definitions for GTK+ packet display structures and routines
  *
- * $Id: proto_draw.h,v 1.10 2000/09/09 10:26:58 guy Exp $
+ * $Id: proto_draw.h,v 1.11 2001/03/23 14:44:04 jfoster Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -26,15 +26,32 @@
 
 #ifndef __GTKPACKET_H__
 #define __GTKPACKET_H__
+#define E_BYTE_VIEW_TEXT_INFO_KEY "byte_view_win"
+#define E_BYTE_VIEW_DATA_PTR_KEY  "byte_view_data"
+#define E_BYTE_VIEW_DATA_LEN_KEY  "byte_view_len"
+#define E_BYTE_VIEW_START_KEY     "byte_view_start"
+#define E_BYTE_VIEW_END_KEY       "byte_view_end"
+#define E_BYTE_VIEW_ENCODE_KEY    "byte_view_encode"
+#define E_BYTE_VIEW_NAME_KEY  	  "byte_view_name"
+
+GtkWidget *add_byte_tab( GtkWidget *byte_nb, const char *name, const guint8 *data, int len);
+int add_byte_view( const char *name, const guint8 *data, int len);
+
+void set_notebook_page( GtkWidget *nb_ptr, int num);
+int find_notebook_page( GtkWidget *nb_ptr, gchar *label);
+
+
+GtkWidget *get_byte_view( GtkWidget *byte_view_notebook);
+int get_byte_view_data( GtkWidget *byte_view_notebook, guint8 **data_ptr);
+int get_byte_view_and_data( GtkWidget *byte_view_notebook, GtkWidget **byte_view, guint8 **data_ptr);
+
+void redraw_hex_dump(GtkWidget *nb, frame_data *fd, field_info *finfo);
 
-void redraw_hex_dump(GtkWidget *bv, guint8 *pd, frame_data *fd,
-    field_info *finfo);
 void redraw_hex_dump_all(void);
 void create_byte_view(gint bv_size, GtkWidget *pane, GtkWidget **byte_view_p,
 		GtkWidget **bv_scrollw_p, int pos);
-void packet_hex_print(GtkText *, guint8 *, frame_data *, field_info *);
-
-#define E_TREEINFO_FIELD_INFO_KEY "tree_info_finfo"
+void packet_hex_print(GtkText *, guint8 *, frame_data *, field_info *, int);
+void packet_hex_reprint(GtkText *);
 
 void create_tree_view(gint tv_size, e_prefs *prefs, GtkWidget *pane,
 		GtkWidget **tv_scrollw_p, GtkWidget **tree_view_p, int pos);
