@@ -1,10 +1,10 @@
 /* packet-dns.c
  * Routines for DNS packet disassembly
  *
- * $Id: packet-dns.c,v 1.64 2001/02/20 16:25:52 nneul Exp $
+ * $Id: packet-dns.c,v 1.66 2001/04/23 18:05:18 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -37,9 +37,9 @@
 
 #include <glib.h>
 #include "packet.h"
+#include "ipproto.h"
 #include "resolv.h"
 #include "packet-dns.h"
-#include "packet-ip.h"
 
 static int proto_dns = -1;
 static int hf_dns_response = -1;
