@@ -2,10 +2,10 @@
  * Routines for the Generic Routing Encapsulation (GRE) protocol
  * Brad Robel-Forrest <brad.robel-forrest@watchguard.com>
  *
- * $Id: packet-gre.c,v 1.40 2001/04/03 05:42:11 guy Exp $
+ * $Id: packet-gre.c,v 1.43 2001/04/23 18:11:01 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -36,13 +36,12 @@
 #include <netinet/in.h>
 #endif
 #include <glib.h>
-#include "etypes.h"
-#include "greproto.h"
 #include "packet.h"
-#include "packet-ip.h"
-#include "packet-ipx.h"
 #include "packet-wccp.h"
 #include "in_cksum.h"
+#include "etypes.h"
+#include "greproto.h"
+#include "ipproto.h"
 
 static int proto_gre = -1;
 static int hf_gre_proto = -1;
