@@ -2,10 +2,10 @@
  * Routines for GTP dissection
  * Copyright 2001, Michal Melerowicz <michal.melerowicz@nokia.com>
  *
- * $Id: packet-gtp.c,v 1.3 2001/04/10 19:10:09 guy Exp $
+ * $Id: packet-gtp.c,v 1.5 2001/04/23 18:05:18 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  * 
  * This program is free software; you can redistribute it and/or
@@ -46,7 +46,6 @@
 #endif
 
 #include "packet.h"
-#include "packet-ip.h"
 #include "packet-ipv6.h"
 
 #define UDP_PORT_GTP 3386
