@@ -2,7 +2,7 @@
  * Routines for Sinec H1 packet disassembly
  * Gerrit Gehnen <G.Gehnen@atrie.de>
  *
- * $Id: packet-h1.c,v 1.17 2001/01/09 06:31:36 guy Exp $
+ * $Id: packet-h1.c,v 1.18 2001/01/22 08:03:45 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -114,16 +114,18 @@ static gboolean dissect_h1(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
   unsigned int position = 3;
   unsigned int offset=0;
 
-  if (!proto_is_protocol_enabled(proto_h1))
-    return FALSE;
+  if (tvb_length_remaining(tvb, 0) < 2)
+    {
+      /* Not enough data captured to hold the "S5" header; don't try
+         to interpret it as H1. */
+      return FALSE;
+    }
 
   if (!(tvb_get_guint8(tvb,offset) == 'S' && tvb_get_guint8(tvb,offset+1) == '5'))
     {
       return FALSE;
     }
 
-  pinfo->current_proto = "H1";
-
   if (check_col (pinfo->fd, COL_PROTOCOL))
     col_set_str (pinfo->fd, COL_PROTOCOL, "H1");
   if (check_col (pinfo->fd, COL_INFO))
