@@ -1,7 +1,7 @@
 /* packet-icq.c
  * Routines for ICQ packet disassembly
  *
- * $Id: packet-icq.c,v 1.28 2001/03/27 02:01:31 guy Exp $
+ * $Id: packet-icq.c,v 1.30 2001/04/27 01:38:19 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Johan Feyaerts
@@ -90,7 +90,7 @@ dissect_icqv5Server(tvbuff_t *tvb,
 		    int offset,
 		    packet_info *pinfo,
 		    proto_tree *tree,
-		    guint32 pktsize);
+		    int pktsize);
 
 /* Offsets of fields in the ICQ headers */
 /* Can be 0x0002 or 0x0005 */
@@ -555,7 +555,7 @@ icqv5_decode_msgType(proto_tree* tree,
     guint16 msgType;
     gint sep_offset;
     int sz;            /* Size of the current element */
-    int n;
+    unsigned int n;
     static char* url_field_descr[] = {
 	"Description",
 	"URL",
@@ -1953,13 +1953,13 @@ dissect_icqv5Server(tvbuff_t *tvb,
 		    int offset,
 		    packet_info *pinfo,
 		    proto_tree *tree,
-		    guint32 pktsize)
+		    int pktsize)
 {
     /* Server traffic is easy, not encrypted */
     proto_tree *icq_tree = NULL;
     proto_tree *icq_header_tree = NULL;
     proto_item *ti = NULL;
-    int changeCol = (pktsize==(guint32)-1);
+    int changeCol = (pktsize==-1);
 
     guint16 cmd;
     
@@ -2123,7 +2123,7 @@ static void dissect_icqv5(tvbuff_t *tvb,
   if (unknown == 0x0L) {
       dissect_icqv5Client(tvb, pinfo, tree);
   } else {
-      dissect_icqv5Server(tvb, 0, pinfo, tree, (guint32) -1);
+      dissect_icqv5Server(tvb, 0, pinfo, tree, -1);
   }
 }
 
