@@ -2,7 +2,7 @@
  * Routines for NetWare's IPX
  * Gilbert Ramirez <gram@xiexie.org>
  *
- * $Id: packet-ipx.c,v 1.81 2001/04/01 02:47:54 hagbard Exp $
+ * $Id: packet-ipx.c,v 1.85 2001/05/03 22:50:33 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -35,15 +35,13 @@
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
+#include "packet.h"
+#include "packet-ipx.h"
+#include "resolv.h"
 #include "etypes.h"
 #include "ppptypes.h"
 #include "llcsaps.h"
 #include "aftypes.h"
-#include "packet.h"
-#include "packet-ipx.h"
-#include "resolv.h"
-
-#include "packet-snmp.h"
 
 /* The information in this module (IPX, SPX, NCP) comes from:
 	NetWare LAN Analysis, Second Edition
@@ -768,12 +766,12 @@ proto_register_ipx(void)
 	static hf_register_info hf_ipxmsg[] = {
 		{ &hf_msg_conn,
 		{ "Connection Number",			"ipxmsg.conn", 
-		  FT_UINT8,	BASE_NONE,	NULL,	0x0,
+		  FT_UINT8,	BASE_DEC,	NULL,	0x0,
 		  "Connection Number" }},
 
 		{ &hf_msg_sigchar,
 		{ "Signature Char",			"ipxmsg.sigchar", 
-		  FT_UINT8,	BASE_NONE,	VALS(ipxmsg_sigchar_vals),	0x0,
+		  FT_UINT8,	BASE_DEC,	VALS(ipxmsg_sigchar_vals),	0x0,
 		  "Signature Char" }}
 	};
 
@@ -806,6 +804,8 @@ proto_register_ipx(void)
 
 	proto_sap = proto_register_protocol("Service Advertisement Protocol",
 	    "IPX SAP", "ipxsap");
+	register_dissector("ipxsap", dissect_ipxsap, proto_sap);
+
 	proto_register_field_array(proto_sap, hf_sap, array_length(hf_sap));
 
 	proto_register_subtree_array(ett, array_length(ett));
