@@ -8,10 +8,10 @@
  *
  * Copyright 2000, Michael Txen <Michael.Tuexen@icn.siemens.de>
  *
- * $Id: packet-m3ua.c,v 1.4 2001/01/25 06:14:14 guy Exp $
+ * $Id: packet-m3ua.c,v 1.6 2001/04/23 18:05:19 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from README.developer
@@ -55,8 +55,6 @@
 #endif
 
 #include "packet.h"
-#include "packet-ip.h"
-
 
 #define SCTP_PORT_M3UA 2905
 #define M3UA_PAYLOAD_PROTO_ID 3
