@@ -3,10 +3,10 @@
  * 
  * (c) Copyright Ashok Narayanan <ashokn@cisco.com>
  *
- * $Id: packet-mpls.c,v 1.17 2001/01/25 06:14:14 guy Exp $
+ * $Id: packet-mpls.c,v 1.20 2001/04/23 18:05:19 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * 
@@ -43,11 +43,9 @@
 #endif
 
 #include <glib.h>
-#include "etypes.h"
 #include "packet.h"
-#include "packet-ip.h"
 #include "ppptypes.h"
-#include "packet-ppp.h"
+#include "etypes.h"
 
 static gint proto_mpls = -1;
 
@@ -90,7 +88,7 @@ static int mpls_filter[MPLSF_MAX];
 static hf_register_info mplsf_info[] = {
 
 /*    {&mpls_filter[MPLSF_PACKET], 
-     {"MPLS Label Switched Packet", "mpls", FT_UINT8, BASE_NONE, NULL, 0x0, 
+     {"MPLS Label Switched Packet", "mpls", FT_UINT8, BASE_DEC, NULL, 0x0, 
       "" }},*/
 
     {&mpls_filter[MPLSF_LABEL], 
