@@ -2,7 +2,7 @@
  * Routines for NTP packet dissection
  * Copyright 1999, Nathan Neulinger <nneul@umr.edu>
  *
- * $Id: packet-ntp.c,v 1.25 2001/01/22 08:03:45 guy Exp $
+ * $Id: packet-ntp.c,v 1.27 2001/04/09 21:42:01 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -221,7 +221,7 @@ static gint ett_ntp_flags = -1;
  * returns pointer to filled buffer.
  */
 static char *
-ntp_fmt_ts(guint8 *reftime, char* buff)
+ntp_fmt_ts(const guint8 *reftime, char* buff)
 {
 	guint32 tempstmp, tempfrac;
 	time_t temptime;
@@ -260,11 +260,11 @@ dissect_ntp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	gint8		precision;
 	double		rootdelay;
 	double		rootdispersion;
-	guint8		*refid;
-	guint8		*reftime;
-	guint8		*org;
-	guint8		*rec;
-	guint8		*xmt;
+	const guint8	*refid;
+	const guint8	*reftime;
+	const guint8	*org;
+	const guint8	*rec;
+	const guint8	*xmt;
 	gchar		buff[NTP_TS_SIZE];
 	int		i;
 
@@ -315,8 +315,8 @@ dissect_ntp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 		proto_tree_add_uint_format(ntp_tree, hf_ntp_ppoll, tvb, 2, 1,
 					   ppoll,
 					   (((ppoll >= 4) && (ppoll <= 16)) ? 
-					   "Peer Pooling Interval: %u (%u sec)" :
-					   "Peer Pooling Interval: invalid (%u)"),
+					   "Peer Polling Interval: %u (%u sec)" :
+					   "Peer Polling Interval: invalid (%u)"),
 					   ppoll,
 					   1 << ppoll);
 
@@ -372,7 +372,7 @@ dissect_ntp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 			}
 		} else {
 			buff[sizeof(buff) - 1] = '\0';
-			strncpy (buff, get_hostname (tvb_get_ntohl(tvb, 12)),
+			strncpy (buff, get_hostname (htonl(tvb_get_ntohl(tvb, 12))),
 			    sizeof(buff));
 			if (buff[sizeof(buff) - 1] != '\0')
 				strcpy(&buff[sizeof(buff) - 4], "...");
