@@ -2,7 +2,7 @@
  * Routines for OSPF packet disassembly
  * (c) Copyright Hannes R. Boehm <hannes@boehm.org>
  *
- * $Id: packet-ospf.c,v 1.37 2001/02/04 08:21:35 guy Exp $
+ * $Id: packet-ospf.c,v 1.40 2001/05/14 18:25:34 guy Exp $
  *
  * At this time, this module is able to analyze OSPF
  * packets as specified in RFC2328. MOSPF (RFC1584) and other
@@ -12,7 +12,7 @@
  * TOS - support is not fully implemented
  * 
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  * 
  * 
@@ -48,7 +48,7 @@
 
 #include <glib.h>
 #include "packet.h"
-#include "packet-ip.h"
+#include "ipproto.h"
 #include "in_cksum.h"
 #include "ieee-float.h"
 
@@ -85,6 +85,7 @@ static const value_string auth_vals[] = {
 #define OSPF_OPTIONS_NP		0x08
 #define OSPF_OPTIONS_EA		0x10
 #define OSPF_OPTIONS_DC		0x20
+#define OSPF_OPTIONS_O		0x40
 
 #define OSPF_DBD_FLAG_MS	1
 #define OSPF_DBD_FLAG_M		2
@@ -97,7 +98,9 @@ static const value_string auth_vals[] = {
 #define OSPF_LSTYPE_SUMMERY	3
 #define OSPF_LSTYPE_ASBR	4
 #define OSPF_LSTYPE_ASEXT	5
+#define OSPF_LSTYPE_GRPMEMBER	6
 #define OSPF_LSTYPE_ASEXT7	7
+#define OSPF_LSTYPE_EXTATTR	8
 
 /* Opaque LSA types */
 #define OSPF_LSTYPE_OP_LINKLOCAL 9
@@ -115,12 +118,18 @@ static const value_string auth_vals[] = {
 #define OSPF_LSA_MPLS_TE        1
 
 static const value_string ls_type_vals[] = {
-	{OSPF_LSTYPE_ROUTER,  "Router-LSA"               },
-	{OSPF_LSTYPE_NETWORK, "Network-LSA"              },
-	{OSPF_LSTYPE_SUMMERY, "Summary-LSA (IP network)" },
-	{OSPF_LSTYPE_ASBR,    "Summary-LSA (ASBR)"       },
-	{OSPF_LSTYPE_ASEXT,   "AS-External-LSA (ASBR)"   },
-	{0,                    NULL                      }
+	{OSPF_LSTYPE_ROUTER,       "Router-LSA"                   },
+	{OSPF_LSTYPE_NETWORK,      "Network-LSA"                  },
+	{OSPF_LSTYPE_SUMMERY,      "Summary-LSA (IP network)"     },
+	{OSPF_LSTYPE_ASBR,         "Summary-LSA (ASBR)"           },
+	{OSPF_LSTYPE_ASEXT,        "AS-External-LSA (ASBR)"       },
+	{OSPF_LSTYPE_GRPMEMBER,    "Group Membership LSA"         },
+	{OSPF_LSTYPE_ASEXT7,       "NSSA AS-External-LSA"         },
+	{OSPF_LSTYPE_EXTATTR,      "External Attributes LSA"      },
+	{OSPF_LSTYPE_OP_LINKLOCAL, "Opaque LSA, Link-local scope" },
+	{OSPF_LSTYPE_OP_AREALOCAL, "Opaque LSA, Area-local scope" },
+	{OSPF_LSTYPE_OP_ASWIDE,    "Opaque LSA, AS-wide scope"    },
+	{0,                        NULL                           }
 };
 
 static int proto_ospf = -1;
@@ -592,15 +601,17 @@ dissect_ospf_lsa_mpls(tvbuff_t *tvb, int offset, proto_tree *tree,
 		case MPLS_LINK_LOCAL_IF:
 		case MPLS_LINK_REMOTE_IF:
 		    ti = proto_tree_add_text(tlv_tree, tvb, stlv_offset, stlv_len+4,
-					     "%s: %s", stlv_name,
-					     ip_to_str(tvb_get_ptr(tvb, stlv_offset+4, 4)));
+					     "%s", stlv_name);
 		    stlv_tree = proto_item_add_subtree(ti, ett_ospf_lsa_mpls_link_stlv);
 		    proto_tree_add_text(stlv_tree, tvb, stlv_offset, 2,
 					"TLV Type: %u: %s", stlv_type, stlv_name);
 		    proto_tree_add_text(stlv_tree, tvb, stlv_offset+2, 2, "TLV Length: %u",
 					stlv_len);
-		    proto_tree_add_text(stlv_tree, tvb, stlv_offset+4, 4, "%s: %s", stlv_name,
-					ip_to_str(tvb_get_ptr(tvb, stlv_offset+4, 4)));
+		    /*   The Local/Remote Interface IP Address sub-TLV is TLV type 3/4, and is 4N
+		       octets in length, where N is the number of neighbor addresses. */
+		    for (i=0; i < stlv_len; i+=4)
+		      proto_tree_add_text(stlv_tree, tvb, stlv_offset+4+i, 4, "%s: %s", stlv_name,
+					  ip_to_str(tvb_get_ptr(tvb, stlv_offset+4+i, 4)));
 		    break;
 
 		case MPLS_LINK_TE_METRIC:
@@ -1017,6 +1028,11 @@ dissect_ospf_options(tvbuff_t *tvb, int offset, proto_tree *tree)
 	    strcat(options_string, "/");
 	strcat(options_string, "DC");
     }
+    if (options & OSPF_OPTIONS_O) {
+	if (options_string[0] != '\0')
+	    strcat(options_string, "/");
+	strcat(options_string, "O");
+    }
 
     proto_tree_add_text(tree, tvb, offset, 1, "Options: 0x%x (%s)",
 			options, options_string);
