@@ -1,10 +1,10 @@
 /* packet-ppp.c
  * Routines for ppp packet disassembly
  *
- * $Id: packet-ppp.c,v 1.61 2001/03/31 10:35:54 guy Exp $
+ * $Id: packet-ppp.c,v 1.63 2001/04/23 18:19:03 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  *
  * This file created and by Mike Hall <mlh@io.com>
  * Copyright 1998
@@ -41,7 +41,6 @@
 #include "atalk-utils.h"
 #include "packet-chdlc.h"
 #include "packet-ip.h"
-#include "packet-ipv6.h"
 #include "packet-ipx.h"
 #include "packet-vines.h"
 #include "nlpid.h"
@@ -93,6 +92,7 @@ static gint ppp_fcs_decode = 0; /* 0 = No FCS, 1 = 16 bit FCS, 2 = 32 bit FCS */
 
 static const value_string ppp_vals[] = {
 	{PPP_IP,        "IP"             },
+	{PPP_OSI,       "OSI"            },
 	{PPP_AT,        "Appletalk"      },
 	{PPP_IPX,       "Netware IPX/SPX"},
 	{PPP_VJC_COMP,	"VJ compressed TCP"},
@@ -106,6 +106,7 @@ static const value_string ppp_vals[] = {
 	{PPP_MPLS_UNI,  "MPLS Unicast"},
 	{PPP_MPLS_MULTI, "MPLS Multicast"},
 	{PPP_IPCP,	"IP Control Protocol" },
+	{PPP_OSICP,     "OSI Control Protocol" },
 	{PPP_ATCP,	"AppleTalk Control Protocol" },
 	{PPP_IPXCP,	"IPX Control Protocol" },
 	{PPP_CCP,	"Compression Control Protocol" },
