@@ -2,7 +2,7 @@
  * Routines for Q.931 frame disassembly
  * Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-q931.c,v 1.23 2001/02/11 23:19:00 guy Exp $
+ * $Id: packet-q931.c,v 1.28 2001/03/30 07:57:38 guy Exp $
  *
  * Modified by Andreas Sikkema for possible use with H.323
  *
@@ -42,8 +42,8 @@
 #include "nlpid.h"
 #include "packet-q931.h"
 
-#ifdef H323
 #include "packet-tpkt.h"
+#ifdef H323
 #include "packet-h225.h"
 #endif
 
@@ -78,7 +78,7 @@ static gint ett_q931_ie = -1;
 #define	Q931_CONNECT_ACK	0x0F
 #define	Q931_PROGRESS		0x03
 #define	Q931_SETUP		0x05
-#define	Q931_SETUP_ACK		0x0B
+#define	Q931_SETUP_ACK		0x0D
 #define	Q931_HOLD		0x24
 #define	Q931_HOLD_ACK		0x28
 #define	Q931_HOLD_REJECT	0x30
@@ -516,43 +516,35 @@ static const value_string q931_uil3_vals[] = {
 	{ 0,			NULL }
 };
 
-/*
- * XXX - should this (or, rather, a routine to return a string containing
- * the stuff we put after "Protocol discriminator:") be in "packet-osi.c"?
- *
- * I.e., is the convention that 16-63 and 80-254 are for network-layer
- * or layer-3 protocols, and 64-79 are for national use, specific to
- * Q.931 (and maybe Q.2931), or is it a more general ISO standard?
- */
 static void 
 dissect_q931_protocol_discriminator(tvbuff_t *tvb, int offset, proto_tree *tree)
 {
 	unsigned int discriminator = tvb_get_guint8(tvb, offset);
-	char *nlpid_string;
 
-	nlpid_string = match_strval(discriminator, nlpid_vals);
-	if (nlpid_string != NULL) {
+	if (discriminator == NLPID_Q_931) {
 		proto_tree_add_uint_format(tree, hf_q931_discriminator,
 			 tvb, offset, 1, discriminator,
-			 "Protocol discriminator: %s", nlpid_string);
+			 "Protocol discriminator: Q.931");
+	} else if (discriminator == NLPID_Q_2931) {
+		proto_tree_add_uint_format(tree, hf_q931_discriminator,
+			 tvb, offset, 1, discriminator,
+			 "Protocol discriminator: Q.2931");
+	} else if ((discriminator >= 16 && discriminator < 63)
+	    || ((discriminator >= 80) && (discriminator < 254))) {
+		proto_tree_add_uint_format(tree, hf_q931_discriminator,
+		    tvb, offset, 1, discriminator,
+		    "Protocol discriminator: Network layer or layer 3 protocol (0x%02X)",
+		    discriminator);
+	} else if (discriminator >= 64 && discriminator <= 79) {
+		proto_tree_add_uint_format(tree, hf_q931_discriminator,
+		    tvb, offset, 1, discriminator,
+		    "Protocol discriminator: National use (0x%02X)",
+		    discriminator);
 	} else {
-		if ((discriminator >= 16 && discriminator < 63)
-		    || ((discriminator >= 80) && (discriminator < 254))) {
-			proto_tree_add_uint_format(tree, hf_q931_discriminator,
-			    tvb, offset, 1, discriminator,
-			    "Protocol discriminator: Network layer or layer 3 protocol (0x%02X)",
-			    discriminator);
-		} else if (discriminator >= 64 && discriminator <= 79) {
-			proto_tree_add_uint_format(tree, hf_q931_discriminator,
-			    tvb, offset, 1, discriminator,
-			    "Protocol discriminator: National use (0x%02X)",
-			    discriminator);
-		} else {
-			proto_tree_add_uint_format(tree, hf_q931_discriminator,
-			    tvb, offset, 1, discriminator,
-			    "Protocol discriminator: Reserved (0x%02X)",
-			    discriminator);
-		}
+		proto_tree_add_uint_format(tree, hf_q931_discriminator,
+		    tvb, offset, 1, discriminator,
+		    "Protocol discriminator: Reserved (0x%02X)",
+		    discriminator);
 	}
 }
 
@@ -1095,14 +1087,15 @@ static const value_string q931_call_state_vals[] = {
 	{ 0x04, "Call delivered" },
 	{ 0x06, "Call present" },
 	{ 0x07, "Call received" },
-	{ 0x09, "Connect request" },
-	{ 0x0A, "Incoming call proceeding" },
-	{ 0x0B, "Active" },
-	{ 0x0C, "Disconnect request" },
-	{ 0x0F, "Disconnect indication" },
-	{ 0x11, "Suspend request" },
-	{ 0x13, "Resume request" },
-	{ 0x16, "Release request" },
+	{ 0x08, "Connect request" },
+	{ 0x09, "Incoming call proceeding" },
+	{ 0x0A, "Active" },
+	{ 0x0B, "Disconnect request" },
+	{ 0x0C, "Disconnect indication" },
+	{ 0x0F, "Suspend request" },
+	{ 0x12, "Resume request" },
+	{ 0x13, "Release request" },
+	{ 0x16, "Call abort"},
 	{ 0x19, "Overlap receiving" },
 	{ 0x3D, "Restart request" },
 	{ 0x3E, "Restart" },
@@ -2119,13 +2112,14 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	int		codeset; 
 	gboolean	non_locking_shift;
 	guint8		protocol_discriminator;
+	int		lv_tpkt_len;
 
 #ifdef H323
 	tvbuff_t	*h225_tvb;
 	gboolean	is_h323_h225 = FALSE;
 	/*
 	 * It is very much possible to find a TPKT header here
-	 * TPKT is defined in RFC 1009 as a wrapper around ISO
+	 * TPKT is defined in RFC 1006 as a wrapper around ISO
 	 * defined protocols. There could even be several TPKT
 	 * wrapped messages in one TCP data field...
 	 * XXXXXXXX THIS IS NOT IMPLEMENTED YET!!! XXXXXXXXXXX
@@ -2141,7 +2135,6 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	protocol_discriminator = tvb_get_guint8( tvb, offset );
 	    /* Keep the protocol discriminator for later use */
 
-#ifdef H323
 	if ( started_heuristic ) {
 		/*
 		 * The heuristic Q.931 message should conform to this
@@ -2159,7 +2152,7 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 	/* 
 	 * The first byte should be < 8 (3 is TPKT, rest is Q.931)
 	 */
-	if ( protocol_discriminator < 8 ) {
+	if ( protocol_discriminator < NLPID_Q_931 ) {
 		/*
 		 * The minimum length of a Q.931 message is 3:
 		 * 1 byte for the protocol discriminator,
@@ -2173,7 +2166,7 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		 * OK, there are a couple of bytes available, but is there 
 		 * also a protocol discriminator?
 		 */
-		if ( tvb_length_remaining( tvb, offset ) > 3 ) {
+		if ( tvb_length_remaining( tvb, offset ) > 4 ) {
 			/* Reread the protocol discriminator */
 			protocol_discriminator =
 			    tvb_get_guint8( tvb, offset + 4);
@@ -2186,7 +2179,7 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		 * If it's not H.323 related Q.931 no heuristic action needed
  		 * Dangerous, there might be other uses for this code.....
 		 */
-		if ( ( started_heuristic ) && (protocol_discriminator != 8 ) ) 
+		if (started_heuristic && protocol_discriminator != NLPID_Q_931) 
 			return FALSE;
 
 		/*
@@ -2195,7 +2188,22 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		if ( ! is_tpkt( tvb, &offset ) ) 
 			return FALSE;
 
-		dissect_tpkt( tvb, &offset, pinfo, tree );
+		lv_tpkt_len = dissect_tpkt_header( tvb, &offset, pinfo, tree );
+		if (lv_tpkt_len == -1) {
+			/*
+			 * TPKT isn't enabled.
+			 */
+			return FALSE;
+		}
+
+		/*
+		 * Check if it's an empty TPKT message (the next one might be a 
+		 * real Q.931 message)
+		 * Skip TPKT length!
+		 */
+		if ( tvb_length_remaining( tvb, offset ) < lv_tpkt_len - 4 ) {
+			return TRUE;
+		}
 
 		/*
 		 * Reset the current_proto variable because dissect_tpkt
@@ -2206,7 +2214,6 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		else 
 			pinfo->current_proto = "Q.931";
 	}
-#endif
 
 	/*
 	 * The minimum length of a Q.931 message is
@@ -2225,7 +2232,7 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 		    tvb_length(tvb), FALSE);
 		q931_tree = proto_item_add_subtree(ti, ett_q931);
 
-		dissect_q931_protocol_discriminator( tvb, offset, q931_tree );
+		dissect_q931_protocol_discriminator(tvb, offset, q931_tree);
 	}
 	offset += 1;
 	call_ref_len = tvb_get_guint8(tvb, offset) & 0xF;	/* XXX - do as a bit field? */
@@ -2583,7 +2590,6 @@ q931_dissector(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree,
 
 }
 
-#ifdef H323
 gboolean
 dissect_q931_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 {
@@ -2599,7 +2605,6 @@ dissect_q931_heur(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	pinfo->current_proto = "Q.931 HEUR";
 	return q931_dissector(tvb, pinfo, tree, TRUE);
 }
-#endif
 
 void
 dissect_q931(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
@@ -2643,7 +2648,5 @@ proto_register_q931(void)
 void
 proto_reg_handoff_q931(void)
 {
-#ifdef H323
-	heur_dissector_add("tcp", dissect_q931_heur);
-#endif
+	heur_dissector_add("tcp", dissect_q931_heur, proto_q931);
 }
