@@ -4,7 +4,7 @@
  * Jason Lango <jal@netapp.com>
  * Liberally copied from packet-http.c, by Guy Harris <guy@alum.mit.edu>
  *
- * $Id: packet-rtsp.c,v 1.34 2001/01/11 20:14:24 guy Exp $
+ * $Id: packet-rtsp.c,v 1.36 2001/01/25 06:14:14 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -96,7 +96,7 @@ dissect_rtspinterleaved(tvbuff_t *tvb, int offset, packet_info *pinfo,
 		return -1;
 	}
 
-	ti = proto_tree_add_text(tree, tvb, offset, 4,
+	ti = proto_tree_add_protocol_format(tree, proto_rtsp, tvb, offset, 4,
 		"RTSP Interleaved Frame, Channel: 0x%02x, %u bytes",
 		rf_chan, rf_len);
 	rtspframe_tree = proto_item_add_subtree(ti, ett_rtspframe);
@@ -659,12 +659,10 @@ dissect_rtsp(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	int		offset = 0;
 	int		len;
 
-	CHECK_DISPLAY_AS_DATA(proto_rtsp, tvb, pinfo, tree);
-
-	pinfo->current_proto = "RTSP";
-
 	if (check_col(pinfo->fd, COL_PROTOCOL))
 		col_set_str(pinfo->fd, COL_PROTOCOL, "RTSP");
+	if (check_col(pinfo->fd, COL_INFO))
+		col_clear(pinfo->fd, COL_INFO);
 
 	while (tvb_offset_exists(tvb, offset)) {
 		len = (tvb_get_guint8(tvb, offset) == RTSP_FRAMEHDR)
