@@ -2,10 +2,10 @@
  * Routines for Stream Control Transmission Protocol dissection
  * Copyright 2000, Michael Txen <Michael.Tuexen@icn.siemens.de>
  *
- * $Id: packet-sctp.c,v 1.14 2001/04/09 00:21:07 guy Exp $
+ * $Id: packet-sctp.c,v 1.16 2001/04/23 17:51:33 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@unicom.net>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Copied from README.developer
@@ -49,7 +49,7 @@
 #endif
 
 #include "packet.h"
-#include "packet-ip.h"
+#include "ipproto.h"
 
 /* Initialize the protocol and registered fields */
 static int proto_sctp = -1;
