@@ -1,8 +1,8 @@
 /* packet-smb-pipe.c
- * Routines for smb packet dissection
+ * Routines for SMB named pipe packet dissection
  * Copyright 1999, Richard Sharpe <rsharpe@ns.aus.com>
  *
- * $Id: packet-smb-pipe.c,v 1.15 2001/01/03 06:55:32 guy Exp $
+ * $Id: packet-smb-pipe.c,v 1.21 2001/03/22 00:50:44 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -48,6 +48,7 @@
 #include "smb.h"
 #include "alignment.h"
 #include "strutil.h"
+#include "packet-smb-pipe.h"
 
 static int proto_smb_lanman = -1;
 
@@ -129,7 +130,7 @@ struct lanman_desc lmd[] = {
   {-1, NULL, NULL,NULL, NULL, NULL}
 };
 
-struct lanman_desc *
+static struct lanman_desc *
 find_lanman(int lanman_num)
 {
   int i = 0;
@@ -156,7 +157,8 @@ find_lanman(int lanman_num)
 #define NETSHAREENUM   0x00  /* 00  */
 #define NETSERVERENUM2 0x68  /* 104 */
 
-void dissect_server_flags(proto_tree *tree, int offset, int length, int flags)
+static void
+dissect_server_flags(proto_tree *tree, int offset, int length, int flags)
 {
   proto_tree_add_text(tree, NullTVB, offset, length, "%s",
 		      decode_boolean_bitfield(flags, 0x0001, length*8, "Workstation", "Not Workstation"));
@@ -217,8 +219,10 @@ static int pd_p_current = 0, pd_d_current = 0, in_params = 0, need_data = 0;
 static int lm_ent_count = 0, lm_act_count = 0; 
 
 /* Initialize the various data structure */
-void 
-dissect_transact_engine_init(const u_char *pd, const char *param_desc, const char *data_desc, int SMB_offset, int ParameterOffset, int ParameterCount, int DataOffset, int DataCount)
+static void 
+dissect_transact_engine_init(const u_char *pd, const char *param_desc,
+    const char *data_desc, int SMB_offset, int ParameterOffset,
+    int ParameterCount, int DataOffset, int DataCount)
 {
 
   d_count = DataCount;
@@ -264,7 +268,7 @@ int get_act_count()
 
 }
 
-int get_byte_count(const u_char *p_data)
+static int get_byte_count(const u_char *p_data)
 
 {
   int count = 0, off = 0;
@@ -283,7 +287,8 @@ int get_byte_count(const u_char *p_data)
 /* We pull out the next item in the appropriate place and display it */
 /* We display the parameters first, then the data, then any auxilliary data */
 
-int dissect_transact_next(const u_char *pd, char *Name, int dirn, proto_tree *tree)
+static int
+dissect_transact_next(const u_char *pd, char *Name, int dirn, proto_tree *tree)
 {
   /*  guint8        BParam; */
   guint16       WParam = 0;
@@ -553,15 +558,25 @@ static const value_string share_type_vals[] = {
         {0, NULL}
 };
 
-guint32 
+/*
+ * Per-frame data needed to dissect replies.
+ */
+typedef struct {
+  guint16 FunctionCode;
+  gboolean is_continuation;
+} response_data;
+
+static GMemChunk  *lanman_proto_data;
+
+gboolean
 dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 	proto_tree *parent, proto_tree *tree, struct smb_info si,
 	int max_data, int SMB_offset, int errcode, int dirn,
 	const u_char *command, int DataOffset, int DataCount,
-	int ParameterOffset, int ParameterCount) {
-	
-
-  guint32             loc_offset = SMB_offset + ParameterOffset;
+	int ParameterOffset, int ParameterCount)
+{
+  gboolean            is_interim_response;
+  guint32             loc_offset;
   guint16             FunctionCode;
   guint16             Level;
   guint16             RecvBufLen;
@@ -573,8 +588,25 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
   struct lanman_desc  *lanman;
   guint32             string_offset;
 
+  if (DataOffset < 0) {
+
+    /* Interim response; we weren't given any data. */
+
+    is_interim_response = TRUE;
+    loc_offset = SMB_offset;
+
+  }
+  else {
+
+    /* Offset of the data we should dissect. */
+
+    is_interim_response = FALSE;
+    loc_offset = SMB_offset + ParameterOffset;
+
+  }
+
   if (check_col(fd, COL_PROTOCOL))
-    col_add_fstr(fd, COL_PROTOCOL, "LANMAN");
+    col_set_str(fd, COL_PROTOCOL, "LANMAN");
 
   if (dirn == 1) { /* The request side */
 
@@ -582,59 +614,74 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 
     si.request_val -> last_lanman_cmd = FunctionCode;
 
+    lanman = find_lanman(FunctionCode);
+
+    if (check_col(fd, COL_INFO)) {
+
+      if (lanman) { 
+	col_add_fstr(fd, COL_INFO, "%s Request", lanman -> lanman_name);
+      }
+      else {
+	col_add_fstr(fd, COL_INFO, "Unknown LANMAN Request: %u", FunctionCode);
+      }
+    }
+
+    if (tree) {
+
+      ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, loc_offset, ParameterCount, FALSE);
+      lanman_tree = proto_item_add_subtree(ti, ett_lanman);
+
+      if (lanman) {
+	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: %s", lanman -> lanman_name);
+      }
+      else {
+	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: Unknown LANMAN Request: %u", FunctionCode);
+      }
+
+    }
+
+    loc_offset += 2;
+
+    ParameterDescriptor = pd + loc_offset;
+
+    /* Now, save these for later */
+
+    si.request_val -> trans_response_seen = 0; 
+
+    if (si.request_val -> last_param_descrip)
+      g_free(si.request_val -> last_param_descrip);
+    si.request_val -> last_param_descrip = g_malloc(strlen(ParameterDescriptor) + 1);
+    if (si.request_val -> last_param_descrip)
+      strcpy(si.request_val -> last_param_descrip, ParameterDescriptor);
+
+    if (tree) {
+
+      proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ParameterDescriptor) + 1, "Parameter Descriptor: %s", ParameterDescriptor);
+
+    }
+
+    loc_offset += strlen(ParameterDescriptor) + 1;
+
+    ReturnDescriptor = pd + loc_offset;
+
+    if (si.request_val -> last_data_descrip)
+      g_free(si.request_val -> last_data_descrip);
+    si.request_val -> last_data_descrip = g_malloc(strlen(ReturnDescriptor) + 1);
+    if (si.request_val -> last_data_descrip)
+      strcpy(si.request_val -> last_data_descrip, ReturnDescriptor);
+
+    if (tree) {
+
+      proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ReturnDescriptor) + 1, "Return Descriptor: %s", ReturnDescriptor);
+
+    }
+
+    loc_offset += strlen(ReturnDescriptor) + 1;
+
     switch (FunctionCode) {
 
     case NETSHAREENUM:   /* Never decode this at the moment ... */
 
-      if (check_col(fd, COL_INFO)) {
-
-	col_add_fstr(fd, COL_INFO, "NetShareEnum Request");
-
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, ParameterCount, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: NetShareEnum");
-
-      }
-
-      loc_offset += 2;
-
-      ParameterDescriptor = pd + loc_offset;
-
-      si.request_val -> trans_response_seen = 0; 
-
-      if (si.request_val -> last_param_descrip) g_free(si.request_val -> last_param_descrip);
-      si.request_val -> last_param_descrip = g_malloc(strlen(ParameterDescriptor) + 1);
-      if (si.request_val -> last_param_descrip)
-	strcpy(si.request_val -> last_param_descrip, ParameterDescriptor);
-
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ParameterDescriptor) + 1, "Parameter Descriptor: %s", ParameterDescriptor);
-
-      }
-
-      loc_offset += strlen(ParameterDescriptor) + 1;
-
-      ReturnDescriptor = pd + loc_offset;
-
-      if (si.request_val -> last_data_descrip) g_free(si.request_val -> last_data_descrip);
-      si.request_val -> last_data_descrip = g_malloc(strlen(ReturnDescriptor) + 1);
-      if (si.request_val -> last_data_descrip)
-	strcpy(si.request_val -> last_data_descrip, ReturnDescriptor);
-
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ReturnDescriptor) + 1, "Return Descriptor: %s", ReturnDescriptor);
-
-      }
-
-      loc_offset += strlen(ReturnDescriptor) + 1;
-
       Level = GSHORT(pd, loc_offset);
       
       if (tree) {
@@ -659,58 +706,6 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 
     case NETSERVERENUM2:  /* Process a NetServerEnum2 */
 
-      if (check_col(fd, COL_INFO)) {
-
-	col_add_fstr(fd, COL_INFO, "NetServerEnum2 %s", dirn ? "Request" : "Response");
-
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, ParameterCount, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-      
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: NetServerEnum2");
-
-      }
-
-      loc_offset += 2;
-
-      ParameterDescriptor = pd + loc_offset;
-
-      /* Now, save these for later */
-
-      si.request_val -> trans_response_seen = 0; 
-
-      if (si.request_val -> last_param_descrip) g_free(si.request_val -> last_param_descrip);
-      si.request_val -> last_param_descrip = g_malloc(strlen(ParameterDescriptor) + 1);
-      if (si.request_val -> last_param_descrip)
-	strcpy(si.request_val -> last_param_descrip, ParameterDescriptor);
-
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ParameterDescriptor) + 1, "Parameter Descriptor: %s", ParameterDescriptor);
-
-      }
-
-      loc_offset += strlen(ParameterDescriptor) + 1;
-
-      ReturnDescriptor = pd + loc_offset;
-
-      if (si.request_val -> last_data_descrip) g_free(si.request_val -> last_data_descrip);
-
-      si.request_val -> last_data_descrip = g_malloc(strlen(ReturnDescriptor) + 1);
-      if (si.request_val -> last_data_descrip)
-	strcpy(si.request_val -> last_data_descrip, ReturnDescriptor);
-      
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ReturnDescriptor) + 1, "Return Descriptor: %s", ReturnDescriptor);
-
-      }
-
-      loc_offset += strlen(ReturnDescriptor) + 1;
-
       Level = GSHORT(pd, loc_offset);
       si.request_val -> last_level = Level;
 
@@ -744,70 +739,10 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 
       loc_offset += 4;
 
-      return 1;
+      return TRUE;
       break;
 
-      default:   /* Just try to handle what is there ... */
-
-      lanman = find_lanman(FunctionCode);
-
-      if (check_col(fd, COL_INFO)) {
-
-	if (lanman) { 
-	  col_add_fstr(fd, COL_INFO, "%s Request", lanman -> lanman_name);
-	}
-	else {
-	  col_add_fstr(fd, COL_INFO, "Unknown LANMAN Request: %u", FunctionCode);
-	}
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, ParameterCount, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-
-	if (lanman) {
-	  proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "%s Request", lanman -> lanman_name);
-	}
-	else {
-	  proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: Unknown LANMAN Request: %u", FunctionCode);
-	}
-
-      }
-
-      loc_offset += 2;
-
-      ParameterDescriptor = pd + loc_offset;
-
-      si.request_val -> trans_response_seen = 0; 
-
-      if (si.request_val -> last_param_descrip) g_free(si.request_val -> last_param_descrip);
-      si.request_val -> last_param_descrip = g_malloc(strlen(ParameterDescriptor) + 1);
-      if (si.request_val -> last_param_descrip)
-	strcpy(si.request_val -> last_param_descrip, ParameterDescriptor);
-
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ParameterDescriptor) + 1, "Parameter Descriptor: %s", ParameterDescriptor);
-
-      }
-
-      loc_offset += strlen(ParameterDescriptor) + 1;
-
-      ReturnDescriptor = pd + loc_offset;
-
-      if (si.request_val -> last_data_descrip) g_free(si.request_val -> last_data_descrip);
-      si.request_val -> last_data_descrip = g_malloc(strlen(ReturnDescriptor) + 1);
-      if (si.request_val -> last_data_descrip)
-	strcpy(si.request_val -> last_data_descrip, ReturnDescriptor);
-
-      if (tree) {
-
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, strlen(ReturnDescriptor) + 1, "Return Descriptor: %s", ReturnDescriptor);
-
-      }
-
-      loc_offset += strlen(ReturnDescriptor) + 1;
+    default:   /* Just try to handle what is there ... */
 
       if (tree) {
 
@@ -826,70 +761,98 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
     
     }
   }
-  else {  /* Dirn == 0, response */
+  else {  /* dirn == 0, response */
+    response_data    *proto_data;
     guint16          Status;
     guint16          Convert;
     guint16          EntCount;
     guint16          AvailCount;
-    guint32          loc_offset = 0;
     int              i;
     proto_tree       *server_tree = NULL, *flags_tree = NULL, *share_tree = NULL;
 
-    FunctionCode = si.request_val -> last_lanman_cmd;
+    /* Is there any per-frame LANMAN data for this frame? */
+    proto_data = p_get_proto_data(fd, proto_smb_lanman);
+    if (proto_data == NULL) {
+      /* No.  Allocate some, and set it up. */
+      proto_data = g_mem_chunk_alloc(lanman_proto_data);
+      proto_data->FunctionCode = si.request_val -> last_lanman_cmd;
+
+      /*
+       * If we've already seen a response to the request, this must
+       * be a continuation of that response.
+       */
+      proto_data->is_continuation = si.request_val -> trans_response_seen;
+
+      /*
+       * Attach it to the frame.
+       */
+      p_add_proto_data(fd, proto_smb_lanman, proto_data);
+    }
+
+    FunctionCode = proto_data->FunctionCode;
 
     /*
      * If we have already seen the response to this transact, simply
      * record it as a continuation ...
      */
-
-/*$$    printf("TransResponseSeen = %u\n", si.request_val -> trans_response_seen);
-*/
-    if (si.request_val -> trans_response_seen == 1) {
+    if (proto_data->is_continuation) {
 
       if (check_col(fd, COL_INFO)) {
-	  col_add_fstr(fd, COL_INFO, "Transact Continuation");
+	  col_set_str(fd, COL_INFO, "Transact Continuation");
       }
       
       if (tree) {
 
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + DataOffset, END_OF_FRAME, FALSE);
+	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, loc_offset, END_OF_FRAME, FALSE);
 
 	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
 
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, END_OF_FRAME, "Payload: %s", format_text(pd + SMB_offset + DataOffset, END_OF_FRAME));
+	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, END_OF_FRAME, "Payload: %s", format_text(pd + loc_offset, END_OF_FRAME));
 
       }
 
-      return 1;
-
+      return TRUE;
 
     } 
 
     si.request_val -> trans_response_seen = 1; 
 
+    lanman = find_lanman(FunctionCode);
+
+    if (check_col(fd, COL_INFO)) {
+
+      if (lanman) {
+	col_add_fstr(fd, COL_INFO, "%s %sResponse", lanman -> lanman_name,
+		is_interim_response ? "Interim " : "");
+      }
+      else {
+	col_add_fstr(fd, COL_INFO, "Unknown LANMAN %sResponse: %u",
+		is_interim_response ? "Interim " : "", FunctionCode);
+      }
+    }
+
+    if (tree) {
+
+      ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, loc_offset, END_OF_FRAME, FALSE);
+      lanman_tree = proto_item_add_subtree(ti, ett_lanman);
+      if (lanman) {
+	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 0, "Function Code: %s", lanman -> lanman_name);
+      }
+      else {
+	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 0, "Function Code: Unknown LANMAN Response: %u", FunctionCode);
+      }
+    }
+
+    if (is_interim_response) {
+
+      return TRUE;	/* no data to dissect */
+
+    }
+
     switch (FunctionCode) {
 
     case NETSHAREENUM:
 
-      if (check_col(fd, COL_INFO)) {
-
-	col_add_fstr(fd, COL_INFO, "NetShareEnum Response");
-
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, END_OF_FRAME, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-      
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 0, "Function Code: NetShareEnum");
-
-      }
-
-      si.request_val -> trans_response_seen = 1; 
-
-      loc_offset = SMB_offset + ParameterOffset;
-
       Status = GSHORT(pd, loc_offset);
 
       if (tree) {
@@ -996,22 +959,6 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 
     case NETSERVERENUM2:
 
-      if (check_col(fd, COL_INFO)) {
-
-	col_add_fstr(fd, COL_INFO, "NetServerEnum2 %s", dirn ? "Request" : "Response");
-
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, END_OF_FRAME, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-      
-	proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 2, "Function Code: NetServerEnum2");
-
-      }
-
-      loc_offset = SMB_offset + ParameterOffset;
       Status = GSHORT(pd, loc_offset);
 
       if (tree) {
@@ -1153,32 +1100,6 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 
     default:
 
-      lanman = find_lanman(si.request_val -> last_lanman_cmd);
-
-      if (check_col(fd, COL_INFO)) {
-
-	if (lanman) {
-	  col_add_fstr(fd, COL_INFO, "%s Response", lanman -> lanman_name);
-	}
-	else {
-	  col_add_fstr(fd, COL_INFO, "Unknown LANMAN Response: %u", FunctionCode);
-	}
-      }
-
-      if (tree) {
-
-	ti = proto_tree_add_item(parent, proto_smb_lanman, NullTVB, SMB_offset + ParameterOffset, END_OF_FRAME, FALSE);
-	lanman_tree = proto_item_add_subtree(ti, ett_lanman);
-	if (lanman) {
-	  proto_tree_add_text(lanman_tree, NullTVB, 0, 0, "%s Response", lanman -> lanman_name);
-	}
-	else {
-	  proto_tree_add_text(lanman_tree, NullTVB, loc_offset, 0, "Function Code: Unknown LANMAN Response: %u", FunctionCode);
-	}
-      }
-
-      loc_offset = SMB_offset + ParameterOffset;
-
       Status = GSHORT(pd, loc_offset);
 
       if (tree) {
@@ -1213,36 +1134,48 @@ dissect_pipe_lanman(const u_char *pd, int offset, frame_data *fd,
 	  
       }
 
-      return 1;
+      return TRUE;
       break;
 
     }
 
   }
 
-  return 0;
+  return FALSE;
 
 }
 
-guint32
+gboolean
 dissect_pipe_smb(const u_char *pd, int offset, frame_data *fd, proto_tree *parent, proto_tree *tree, struct smb_info si, int max_data, int SMB_offset, int errcode, int dirn, const u_char *command, int DataOffset, int DataCount, int ParameterOffset, int ParameterCount)
 {
 
   if (!proto_is_protocol_enabled(proto_smb_lanman))
-    return 0;
+    return FALSE;
 
-  if (command != NULL && strcmp(command, "LANMAN") == 0) { /* Try to decode a LANMAN */
+  if (command != NULL && strcmp(command, "LANMAN") == 0) {
+    /* Try to decode a LANMAN */
 
-    return dissect_pipe_lanman(pd, offset, fd, parent, tree, si, max_data, SMB_offset, errcode, dirn, command, DataOffset, DataCount, ParameterOffset, ParameterCount);
+    return dissect_pipe_lanman(pd, offset, fd, parent, tree, si, max_data,
+			       SMB_offset, errcode, dirn, command, DataOffset,
+			       DataCount, ParameterOffset, ParameterCount);
 
   }
 
-  return 0;
+  return FALSE;
 
 }
 
+static void
+pipe_lanman_init_protocol(void)
+{
+  if (lanman_proto_data != NULL)
+    g_mem_chunk_destroy(lanman_proto_data);
 
-
+  lanman_proto_data = g_mem_chunk_new("lanman_proto_data",
+				      sizeof(response_data),
+				      100 * sizeof(response_data),
+				      G_ALLOC_AND_FREE);
+}
 
 void
 register_proto_smb_pipe( void){
@@ -1263,4 +1196,5 @@ register_proto_smb_pipe( void){
     		"Microsoft Windows Lanman Protocol", "LANMAN", "lanman");
 
 	proto_register_subtree_array(ett, array_length(ett));
+	register_init_routine(&pipe_lanman_init_protocol);
 }
