@@ -1,10 +1,10 @@
 /* packet-udp.c
  * Routines for UDP packet disassembly
  *
- * $Id: packet-udp.c,v 1.89 2001/03/28 21:33:31 guy Exp $
+ * $Id: packet-udp.c,v 1.91 2001/04/23 17:56:42 guy Exp $
  *
  * Ethereal - Network traffic analyzer
- * By Gerald Combs <gerald@zing.org>
+ * By Gerald Combs <gerald@ethereal.com>
  * Copyright 1998 Gerald Combs
  *
  * Richard Sharpe, 13-Feb-1999, added dispatch table support and 
@@ -44,13 +44,13 @@
 #include <glib.h>
 #include "globals.h"
 #include "resolv.h"
+#include "ipproto.h"
 #include "in_cksum.h"
 
 #include "packet-udp.h"
 
 #include "packet-ip.h"
 #include "conversation.h"
-#include "packet-vines.h"
 
 static int proto_udp = -1;		
 static int hf_udp_srcport = -1;
