@@ -2,7 +2,7 @@
  *
  * Routines to dissect WTLS component of WAP traffic.
  * 
- * $Id: packet-wtls.c,v 1.4 2001/03/09 04:35:22 guy Exp $
+ * $Id: packet-wtls.c,v 1.8 2001/05/02 22:37:06 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -74,17 +74,21 @@ static int hf_wtls_hands_cli_hello_version    = HF_EMPTY;
 static int hf_wtls_hands_cli_hello_gmt                = HF_EMPTY;
 static int hf_wtls_hands_cli_hello_random     = HF_EMPTY;
 static int hf_wtls_hands_cli_hello_session    = HF_EMPTY;
+static int hf_wtls_hands_cli_hello_session_str    = HF_EMPTY;
 static int hf_wtls_hands_cli_hello_cli_key_id    = HF_EMPTY;
+static int hf_wtls_hands_cli_hello_cli_key_len    = HF_EMPTY;
 static int hf_wtls_hands_cli_hello_trust_key_id    = HF_EMPTY; 
 static int hf_wtls_hands_cli_hello_key_exchange               =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_key_exchange_suite         =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_key_parameter_index                =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_key_parameter_set          =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_key_identifier_type                =HF_EMPTY;
+static int hf_wtls_hands_cli_hello_key_identifier_charset             =HF_EMPTY;
+static int hf_wtls_hands_cli_hello_key_identifier_size                =HF_EMPTY;
+static int hf_wtls_hands_cli_hello_key_identifier                     =HF_EMPTY;
+static int hf_wtls_hands_cli_hello_key_identifier_str                 =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_cipher_suite               =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_cipher_suite_item  =HF_EMPTY;
-static int hf_wtls_hands_cli_hello_cipher_bulk                =HF_EMPTY;
-static int hf_wtls_hands_cli_hello_cipher_mac         =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_compression_methods                =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_compression                =HF_EMPTY;
 static int hf_wtls_hands_cli_hello_sequence_mode      =HF_EMPTY;
@@ -94,6 +98,7 @@ static int hf_wtls_hands_serv_hello_version   = HF_EMPTY;
 static int hf_wtls_hands_serv_hello_gmt               = HF_EMPTY;
 static int hf_wtls_hands_serv_hello_random    = HF_EMPTY;
 static int hf_wtls_hands_serv_hello_session   = HF_EMPTY;
+static int hf_wtls_hands_serv_hello_session_str   = HF_EMPTY;
 static int hf_wtls_hands_serv_hello_cli_key_id                =HF_EMPTY;
 static int hf_wtls_hands_serv_hello_cipher_suite_item =HF_EMPTY;
 static int hf_wtls_hands_serv_hello_cipher_bulk               =HF_EMPTY;
@@ -211,7 +216,7 @@ static const value_string wtls_vals_identifier_type[] = {
 	{ 0, "No identifier" },
 	{ 1, "Textual Name" },
 	{ 2, "Binary Name" },
-	{ 254, "SHA-1 Hash Publie Key" },
+	{ 254, "SHA-1 Hash of Public Key" },
 	{ 255, "x509 Distinguished Name" },
 	{ 0x00, NULL }
 };
@@ -451,6 +456,8 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 	guint public_key = 0;
 	guint signature = 0;
 	char valStr[1024];
+        char *valBulk = NULL;
+        char *valMac = NULL;
 
 	proto_item *ti;
 	proto_item *cli_key_item;
@@ -487,16 +494,50 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					tvb,offset,12,bo_big_endian);
 			offset+=12;
 			count = tvb_get_guint8(tvb, offset);
-			ti = proto_tree_add_item (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session,
-					tvb,offset,count+1,bo_big_endian);
+                        switch(count) {
+                                case 0:
+                                        ti = proto_tree_add_string (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session_str,
+                                                                        tvb,offset,count+1,"NULL");
+                                        break;
+                                case 1 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_guint8(tvb,offset+1));
+                                        break;
+                                case 2 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntohs(tvb,offset+1));
+                                        break;
+                                case 3 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntoh24(tvb,offset+1));
+                                        break;
+                                case 4 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntohl(tvb,offset+1));
+                                        break;
+                                default:
+                                        ti = proto_tree_add_string (wtls_msg_type_item_tree, hf_wtls_hands_cli_hello_session_str,
+                                                                        tvb,offset,count+1,"Too big");
+                                        break;
+                        }
 			offset+=1+count;
+
+			/* process client_key_ids structure */
 			count = tvb_get_ntohs (tvb, offset);
 			ti = proto_tree_add_item(wtls_msg_type_item_tree, 
 					hf_wtls_hands_cli_hello_cli_key_id, tvb, offset,
 					 count+2, bo_little_endian);
 			wtls_msg_type_item_sub_tree = proto_item_add_subtree(ti, ett_wtls_msg_type_item_sub);
+
+			/* display length of client_key_ids structure */
+			ti = proto_tree_add_item(wtls_msg_type_item_sub_tree,
+					hf_wtls_hands_cli_hello_cli_key_len,
+					tvb,offset,2,bo_big_endian);
 			offset+=2;
+
+			/* cycle through client_key_ids entries */
 			for (;count > 0;count-=client_size) {
+				/* get encryption suite id (one byte) */
 				value = tvb_get_guint8 (tvb, offset);
 				cli_key_item = proto_tree_add_uint(wtls_msg_type_item_sub_tree, 
 						hf_wtls_hands_cli_hello_key_exchange, tvb, offset,1,
@@ -508,12 +549,22 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 						hf_wtls_hands_cli_hello_key_exchange_suite,
 						tvb,offset,1,value);
 				offset++;
+#ifdef DEBUG
+				fprintf(stderr, "encryption suite = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* get parameter index (one byte) */
 				value = tvb_get_guint8 (tvb, offset);
 				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 					hf_wtls_hands_cli_hello_key_parameter_index,
 					tvb,offset,1,bo_big_endian);
 				offset++;
 				client_size++;
+#ifdef DEBUG
+				fprintf(stderr, "parameter index = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* explicit parameters present in next field */
 				if (value == 0xff) {
 					size = tvb_get_ntohs (tvb, offset);
 					ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
@@ -522,21 +573,109 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					offset+=size+2;
 					client_size+=size+2;
 				}
+
+				/* get identifier type */
 				value = tvb_get_guint8 (tvb, offset);
 				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 						hf_wtls_hands_cli_hello_key_identifier_type,
 						tvb,offset,1,bo_big_endian);
 				offset++;
 				client_size++;
+#ifdef DEBUG
+				fprintf(stderr, "identifier type = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* identifier present in next field */
+				/* note: value 0x0 means no identifier */
+				switch(value) {
+					case 0x01 :	/* text identifier */
+						/* not teste */
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_charset,
+								tvb,offset,2,bo_big_endian);
+						offset+=2;
+						size = tvb_get_guint8 (tvb, offset);
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						strncpy(valStr,tvb_get_ptr (tvb, offset, size),size);
+						valStr[size]=0;
+						ti = proto_tree_add_string(
+								wtls_msg_type_item_sub_sub_tree, 
+								hf_wtls_hands_cli_hello_key_identifier_str,
+								tvb, offset,size,valStr);
+						offset+=size;
+						client_size+=size+3;
+#ifdef DEBUG
+						fprintf(stderr, "text id size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+					case 0x02 :	/* binary identifier */
+						size = tvb_get_guint8 (tvb, offset);
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,size,bo_big_endian);
+						offset+=size;
+						client_size+=size+1;
+#ifdef DEBUG
+						fprintf(stderr, "binary id size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+					case 0xfe : /* SHA-1 hash of the public key */
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,20,bo_big_endian);
+						offset+=20;
+						client_size+=20;
+#ifdef DEBUG
+						fprintf(stderr, "SHA-1 hash size = 20, client_size = %d\n",
+							client_size);
+#endif /* DEBUG */
+						break;
+					case 0xff : /* X.509 distinguished name */
+						/* not tested */
+						size = tvb_get_guint8 (tvb, offset);
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,size,bo_big_endian);
+						offset+=size;
+						client_size+=size+1;
+#ifdef DEBUG
+						fprintf(stderr, "X.509 name size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+				}
+
 				proto_item_set_len(cli_key_item, client_size);
 			}
+
+			/* process trusted_keys structure */
 			count = tvb_get_ntohs (tvb, offset);
 			ti = proto_tree_add_item(wtls_msg_type_item_tree, 
 					hf_wtls_hands_cli_hello_trust_key_id, tvb, offset,
 					 count+2, bo_little_endian);
 			wtls_msg_type_item_sub_tree = proto_item_add_subtree(ti, ett_wtls_msg_type_item_sub);
+
+			/* display length of trusted_keys structure */
+			ti = proto_tree_add_item(wtls_msg_type_item_sub_tree,
+					hf_wtls_hands_cli_hello_cli_key_len,
+					tvb,offset,2,bo_big_endian);
+
 			offset+=2;
 			for (;count > 0;count-=client_size) {
+				/* get encryption suite id (one byte) */
 				value = tvb_get_guint8 (tvb, offset);
 				cli_key_item = proto_tree_add_uint(wtls_msg_type_item_sub_tree, 
 						hf_wtls_hands_cli_hello_key_exchange, tvb, offset,1,
@@ -548,12 +687,22 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 						hf_wtls_hands_cli_hello_key_exchange_suite,
 						tvb,offset,1,value);
 				offset++;
+#ifdef DEBUG
+				fprintf(stderr, "encryption suite = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* get parameter index (one byte) */
 				value = tvb_get_guint8 (tvb, offset);
 				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 					hf_wtls_hands_cli_hello_key_parameter_index,
 					tvb,offset,1,bo_big_endian);
 				offset++;
 				client_size++;
+#ifdef DEBUG
+				fprintf(stderr, "parameter index = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* explicit parameters present in next field */
 				if (value == 0xff) {
 					size = tvb_get_ntohs (tvb, offset);
 					ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
@@ -562,14 +711,95 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					offset+=size+2;
 					client_size+=size+2;
 				}
+
+				/* get identifier type */
 				value = tvb_get_guint8 (tvb, offset);
 				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
 						hf_wtls_hands_cli_hello_key_identifier_type,
 						tvb,offset,1,bo_big_endian);
 				offset++;
 				client_size++;
+#ifdef DEBUG
+				fprintf(stderr, "identifier type = %d, client_size = %d\n", value, client_size);
+#endif /* DEBUG */
+
+				/* identifier present in next field */
+				/* note: value 0x0 means no identifier */
+				switch (value) {
+					case 0x01 :	/* text identifier */
+						/* not temasted */
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_charset,
+								tvb,offset,2,bo_big_endian);
+						offset+=2;
+						size = tvb_get_guint8 (tvb, offset);
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						strncpy(valStr,tvb_get_ptr (tvb, offset, size),size);
+						valStr[size]=0;
+						ti = proto_tree_add_string(
+								wtls_msg_type_item_sub_sub_tree, 
+								hf_wtls_hands_cli_hello_key_identifier_str,
+								tvb, offset,size,valStr);
+						offset+=size;
+						client_size+=size+3;
+#ifdef DEBUG
+						fprintf(stderr, "text id size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+					case 0x02 : /* binary identifier */
+						size = tvb_get_guint8 (tvb, offset);
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,size,bo_big_endian);
+						offset+=size;
+						client_size+=size+1;
+#ifdef DEBUG
+						fprintf(stderr, "binary id size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+					case 0xfe :	/* SHA-1 hash of the public key */
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,20,bo_big_endian);
+						offset+=20;
+						client_size+=20;
+#ifdef DEBUG
+						fprintf(stderr, "SHA-1 hash size = 20, client_size = %d\n",
+							client_size);
+#endif /* DEBUG */
+						break;
+					case 0xff : 	/* X.509 distinguished name */
+						/* not testet */
+						size = tvb_get_guint8 (tvb, offset);
+						/* need to fetch identifier and display it */
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier_size,
+								tvb,offset,1,bo_big_endian);
+						offset++;
+						ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
+								hf_wtls_hands_cli_hello_key_identifier,
+								tvb,offset,size,bo_big_endian);
+						offset+=size;
+						client_size+=size+1;
+#ifdef DEBUG
+						fprintf(stderr, "X.509 name size = %d, client_size = %d\n",
+							size, client_size);
+#endif /* DEBUG */
+						break;
+				}
 				proto_item_set_len(cli_key_item, client_size);
 			}
+
+			/* process cipher_suites structure */
 			count = tvb_get_guint8 (tvb, offset);
 			ti = proto_tree_add_item(wtls_msg_type_item_tree, 
 					hf_wtls_hands_cli_hello_cipher_suite, tvb, offset,
@@ -577,23 +807,39 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 			wtls_msg_type_item_sub_tree = proto_item_add_subtree(ti, ett_wtls_msg_type_item_sub);
 			offset+=1;
 			for (;count > 0;count-=client_size) {
-				cli_key_item = proto_tree_add_item(wtls_msg_type_item_sub_tree, 
-						hf_wtls_hands_cli_hello_cipher_suite_item, tvb, offset,1,
-						bo_little_endian);
-				client_size=1;
-				wtls_msg_type_item_sub_sub_tree = proto_item_add_subtree(cli_key_item, 
-								  ett_wtls_msg_type_item_sub_sub);
-				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
-						hf_wtls_hands_cli_hello_cipher_bulk,
-						tvb,offset,1,bo_big_endian);
-				offset++;
-				value = tvb_get_guint8 (tvb, offset);
-				ti = proto_tree_add_item(wtls_msg_type_item_sub_sub_tree,
-					hf_wtls_hands_cli_hello_cipher_mac,
-					tvb,offset,1,bo_big_endian);
+			       value = tvb_get_guint8 (tvb, offset);
+                               valBulk = match_strval(value, wtls_vals_cipher_bulk);
+                               offset++;
+                               client_size=1;
+                               valMac = match_strval(tvb_get_guint8 (tvb, offset), wtls_vals_cipher_mac);
+                               if (valBulk != NULL)
+                               {
+                                       if (valMac != NULL)
+                                       {
+                                               snprintf(valStr,1024,"%s, %s",valBulk,valMac);
+                                       }
+                                       else
+                                       {
+                                               snprintf(valStr,1024,"%s, Unknow MAC (0x%02x)",valBulk,tvb_get_guint8 (tvb, offset));
+                                       }
+                               }
+                               else
+                               {
+                                       if (valMac != NULL)
+                                      {
+                                               snprintf(valStr,1024,"Unknow Bulk (0x%02x), %s",value,valMac);
+                                       }
+                                       else
+                                       {
+                                               snprintf(valStr,1024,"Unknow Bulk (0x%02x), Unknow MAC (0x%02x)",value,
+                                                               tvb_get_guint8 (tvb, offset));
+                                       }
+                                }
 				offset++;
 				client_size++;
-				proto_item_set_len(cli_key_item, client_size);
+                                cli_key_item = proto_tree_add_string(wtls_msg_type_item_sub_tree,
+                                               hf_wtls_hands_cli_hello_cipher_suite_item, tvb, offset-2,2,
+                                               valStr); 
 			}
 			count = tvb_get_guint8 (tvb, offset);
 			ti = proto_tree_add_item(wtls_msg_type_item_tree, 
@@ -633,8 +879,32 @@ dissect_wtls_handshake(proto_tree *tree, tvbuff_t *tvb, guint offset, guint coun
 					tvb,offset,12,bo_big_endian);
 			offset+=12;
 			count = tvb_get_guint8(tvb, offset);
-			ti = proto_tree_add_item (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session,
-					tvb,offset,count+1,bo_big_endian);
+                        switch(count) {
+                                case 0:
+                                        ti = proto_tree_add_string (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session_str,
+                                                                        tvb,offset,count+1,"NULL");
+                                        break;
+                                case 1 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_guint8(tvb,offset+1));
+                                        break;
+                                case 2 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntohs(tvb,offset+1));
+                                        break;
+                                case 3 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntoh24(tvb,offset+1));
+                                        break;
+                                case 4 :
+                                        ti = proto_tree_add_uint (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session,
+                                                                        tvb,offset,count+1,tvb_get_ntohl(tvb,offset+1));
+                                        break;
+                                default:
+                                        ti = proto_tree_add_string (wtls_msg_type_item_tree, hf_wtls_hands_serv_hello_session_str,
+                                                                        tvb,offset,count+1,"Too big");
+                                        break;
+                        }
 			offset+=1+count;
 			ti = proto_tree_add_item(wtls_msg_type_item_tree,
 					hf_wtls_hands_serv_hello_cli_key_id,
@@ -871,14 +1141,14 @@ proto_register_wtls(void)
 		{ &hf_wtls_record,
 			{ 	"Record",           
 				"wsp.wtls.record",
-				 FT_UINT8, BASE_NONE, VALS ( wtls_vals_record_type ), 0x0f,
+				 FT_UINT8, BASE_DEC, VALS ( wtls_vals_record_type ), 0x0f,
 				"Record" 
 			}
 		},
 		{ &hf_wtls_record_type,
 			{ 	"Record Type",           
 				"wsp.wtls.rec_type",
-				 FT_UINT8, BASE_NONE, VALS ( wtls_vals_record_type ), 0x0f,
+				 FT_UINT8, BASE_DEC, VALS ( wtls_vals_record_type ), 0x0f,
 				"Record Type" 
 			}
 		},
@@ -955,7 +1225,14 @@ proto_register_wtls(void)
 		{ &hf_wtls_hands_cli_hello_session,
 			{ 	"Session ID",           
 				"wsp.wtls.handshake.client_hello.sessionid",
-				 FT_NONE, BASE_DEC, NULL, 0x00,
+				 FT_UINT32, BASE_DEC, NULL, 0x00,
+				"Session ID" 
+			}
+		},
+		{ &hf_wtls_hands_cli_hello_session_str,
+			{ 	"Session ID",           
+				"wsp.wtls.handshake.client_hello.session.str",
+				 FT_STRING, BASE_DEC, NULL, 0x00,
 				"Session ID" 
 			}
 		},
@@ -966,6 +1243,13 @@ proto_register_wtls(void)
 			 	"Client Keys"           
 			}
 		},
+		{ &hf_wtls_hands_cli_hello_cli_key_len,
+			{ 	"Length",           
+				"wsp.wtls.handshake.client_hello.client_keys_len",
+				 FT_UINT16, BASE_DEC, NULL, 0x00,
+			 	"Length"           
+			}
+		},
 		{ &hf_wtls_hands_cli_hello_trust_key_id,
 			{ 	"Trusted Keys",           
 				"wsp.wtls.handshake.client_hello.trusted_keys_id",
@@ -1008,6 +1292,34 @@ proto_register_wtls(void)
 				"Identifier Type" 
 			}
 		},
+		{ &hf_wtls_hands_cli_hello_key_identifier_charset,
+			{ 	"Identifier CharSet",           
+				"wsp.wtls.handshake.client_hello.ident_charset",
+				 FT_UINT16, BASE_HEX, VALS ( vals_character_sets ), 0x00,
+				"Identifier CharSet" 
+			}
+		},
+		{ &hf_wtls_hands_cli_hello_key_identifier_size,
+			{ 	"Identifier Size",           
+				"wsp.wtls.handshake.client_hello.ident_size",
+				 FT_UINT8, BASE_DEC, NULL, 0x00,
+				"Identifier Size" 
+			}
+		},
+		{ &hf_wtls_hands_cli_hello_key_identifier,
+			{ 	"Identifier",           
+				"wsp.wtls.handshake.client_hello.identifier",
+				 FT_NONE, BASE_HEX, NULL, 0x00,
+				"Identifier" 
+			}
+		},
+		{ &hf_wtls_hands_cli_hello_key_identifier_str,
+			{ 	"Identifier Name",           
+				"wsp.wtls.handshake.client_hello.ident_name",
+				 FT_STRING, BASE_HEX, NULL, 0x00,
+				"Identifier Name" 
+			}
+		},
 		{ &hf_wtls_hands_cli_hello_cipher_suite,
 			{ 	"Cipher Suites",           
 				"wsp.wtls.handshake.client_hello.ciphers",
@@ -1018,24 +1330,10 @@ proto_register_wtls(void)
 		{ &hf_wtls_hands_cli_hello_cipher_suite_item,
 			{ 	"Cipher",           
 				"wsp.wtls.handshake.client_hello.cipher",
-				 FT_NONE, BASE_DEC, NULL, 0x00,
+				 FT_STRING, BASE_DEC, NULL, 0x00,
 				"Cipher" 
 			}
 		},
-		{ &hf_wtls_hands_cli_hello_cipher_bulk,
-			{ 	"Cipher Bulk",           
-				"wsp.wtls.handshake.client_hello.cipher.bulk",
-				 FT_UINT8, BASE_HEX, VALS ( wtls_vals_cipher_bulk ), 0x00,
-				"Cipher Bulk" 
-			}
-		},
-		{ &hf_wtls_hands_cli_hello_cipher_mac,
-			{ 	"Cipher MAC",           
-				"wsp.wtls.handshake.client_hello.cipher.mac",
-				 FT_UINT8, BASE_HEX, VALS ( wtls_vals_cipher_mac ), 0x00,
-				"Cipher MAC" 
-			}
-		},
 		{ &hf_wtls_hands_cli_hello_compression_methods,
 			{ 	"Compression Methods",           
 				"wsp.wtls.handshake.client_hello.comp_methods",
@@ -1095,7 +1393,14 @@ proto_register_wtls(void)
 		{ &hf_wtls_hands_serv_hello_session,
 			{ 	"Session ID",           
 				"wsp.wtls.handshake.server_hello.sessionid",
-				 FT_NONE, BASE_DEC, NULL, 0x00,
+				 FT_UINT32, BASE_DEC, NULL, 0x00,
+				"Session ID" 
+			}
+		},
+		{ &hf_wtls_hands_serv_hello_session_str,
+			{ 	"Session ID",           
+				"wsp.wtls.handshake.server_hello.session.str",
+				 FT_STRING, BASE_DEC, NULL, 0x00,
 				"Session ID" 
 			}
 		},
@@ -1276,7 +1581,7 @@ proto_register_wtls(void)
 		},
 		{ &hf_wtls_hands_certificate_wtls_rsa_modules,
 			{ 	"RSA Modulus Size",           
-				"wsp.wtls.handshake.certificate.rsa.modulus",
+				"wsp.wtls.handshake.certificate.rsa.modules",
 				 FT_UINT32, BASE_DEC, NULL, 0x00,
 				"RSA Modulus Size" 
 			}
