@@ -2,7 +2,7 @@
  * Routines for x25 packet disassembly
  * Olivier Abad <oabad@cybercable.fr>
  *
- * $Id: packet-x25.c,v 1.46 2001/02/12 09:06:17 guy Exp $
+ * $Id: packet-x25.c,v 1.48 2001/04/07 08:33:12 guy Exp $
  *
  * Ethereal - Network traffic analyzer
  * By Gerald Combs <gerald@zing.org>
@@ -36,11 +36,8 @@
 #include <glib.h>
 #include <stdlib.h>
 #include <string.h>
-#include "etypes.h"
 #include "llcsaps.h"
 #include "packet.h"
-#include "packet-ip.h"
-#include "packet-osi.h"
 #include "nlpid.h"
 
 #define FROM_DCE			0x80
@@ -1477,8 +1474,11 @@ dissect_x25(tvbuff_t *tvb, packet_info *pinfo, proto_tree *tree)
 	    spi = tvb_get_guint8(tvb, localoffset);
 	    switch (spi) {
 
-	    /* XXX - handle other NLPIDs, e.g. PPP? */
-
+	    /*
+	     * XXX - handle other NLPIDs, e.g. PPP?
+	     * See RFC 1356 for information on at least some other
+	     * ways of running other protocols atop X.25.
+	     */
 	    case NLPID_IP:
 		x25_hash_add_proto_start(vc, pinfo->fd->abs_secs,
 					 pinfo->fd->abs_usecs, ip_handle);
