@@ -1,6 +1,6 @@
 /* libpcap.c
  *
- * $Id: libpcap.c,v 1.45 2000/12/23 08:06:15 guy Exp $
+ * $Id: libpcap.c,v 1.48 2001/03/15 09:11:03 guy Exp $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@xiexie.org>
@@ -147,7 +147,11 @@ static const struct {
 #if defined(DLT_LOOP) && (DLT_LOOP == 12)
 	{ 12,		WTAP_ENCAP_NULL },
 #elif defined(DLT_C_HDLC) && (DLT_C_HDLC == 12)
-	/* Put entry for Cisco HDLC here */
+	/*
+	 * Put entry for Cisco HDLC here.
+	 * XXX - is this just WTAP_ENCAP_CHDLC, i.e. does the frame
+	 * start with a 4-byte Cisco HDLC header?
+	 */
 #else
 	{ 12,		WTAP_ENCAP_RAW_IP },
 #endif
@@ -208,7 +212,7 @@ static const struct {
 	 *
 	 *	DLT_PPP_BSDOS on BSD/OS;
 	 *
-	 *	DLT_HDLC on NetBSD;
+	 *	DLT_HDLC on NetBSD (Cisco HDLC);
 	 *
 	 *	DLT_CIP with Alexey Kuznetzov's patches for
 	 *	Linux libpcap - this is WTAP_ENCAP_LINUX_ATM_CLIP;
@@ -219,6 +223,9 @@ static const struct {
 #if defined(DLT_CIP) && (DLT_CIP == 16)
 	{ 16,		WTAP_ENCAP_LINUX_ATM_CLIP },
 #endif
+#if defined(DLT_HDLC) && (DLT_HDLC == 16)
+	{ 16,		WTAP_ENCAP_CHDLC },
+#endif
 
 	/*
 	 * 17 is DLT_LANE8023 in SuSE 6.3 libpcap; we don't currently
@@ -293,6 +300,11 @@ static const struct {
 	 * WTAP_ENCAP_PPP now) and "PPP where there's either HDLC
 	 * encapsulation or Cisco PPP" (which is what DLT_PPP_SERIAL
 	 * is) at some point.
+	 *
+	 * XXX - NetBSD has DLT_HDLC, which appears to be used for
+	 * Cisco HDLC.  Ideally, they should use DLT_PPP_SERIAL
+	 * only for real live HDLC-encapsulated PPP, not for Cisco
+	 * HDLC.
 	 */
 	{ 50,		WTAP_ENCAP_PPP },
 
@@ -316,9 +328,12 @@ static const struct {
 	 */
 	{ 102,		WTAP_ENCAP_SLIP_BSDOS },
 	{ 103,		WTAP_ENCAP_PPP_BSDOS },
-	{ 104,		WTAP_ENCAP_C_HDLC },	/* Cisco HDLC */
 #endif
-	/* This one is handled in Ethereal, though. */
+
+	/*
+	 * These ones are handled in Ethereal, though.
+	 */
+	{ 104,		WTAP_ENCAP_CHDLC },	/* Cisco HDLC */
 	{ 106,		WTAP_ENCAP_LINUX_ATM_CLIP },
 
 	/*
@@ -328,7 +343,11 @@ static const struct {
 	 */
 	{ 105,		WTAP_ENCAP_IEEE_802_11 },
 #if 0
-	/* Not yet handled in Ethereal. */
+	/*
+	 * Not yet handled in Ethereal; we don't know what encapsulation
+	 * BSD/OS uses, so we don't know whether it can be handed to
+	 * the Frame Relay dissector or not.
+	 */
 	{ 107,		WTAP_ENCAP_FR },	/* Frame Relay */
 #endif
 	{ 108,		WTAP_ENCAP_NULL },	/* OpenBSD loopback */
@@ -336,8 +355,8 @@ static const struct {
 	{ 109,		WTAP_ENCAP_ENC },	/* OpenBSD IPSEC enc */
 	{ 110,		WTAP_ENCAP_LANE_802_3 },/* ATM LANE 802.3 */
 	{ 111,		WTAP_ENCAP_HIPPI },	/* NetBSD HIPPI */
-	{ 112,		WTAP_ENCAP_HDLC },	/* NetBSD HDLC framing */
 #endif
+	{ 112,		WTAP_ENCAP_CHDLC },	/* NetBSD HDLC framing */
 
 	/*
 	 * Linux "cooked mode" captures, used by the current CVS version
@@ -357,8 +376,6 @@ int libpcap_open(wtap *wth, int *err)
 	int file_encap;
 
 	/* Read in the number that should be at the start of a "libpcap" file */
-	file_seek(wth->fh, 0, SEEK_SET);
-	wth->data_offset = 0;
 	errno = WTAP_ERR_CANT_READ;
 	bytes_read = file_read(&magic, 1, sizeof magic, wth->fh);
 	if (bytes_read != sizeof magic) {
