@@ -1,6 +1,6 @@
 /* netxray.h
  *
- * $Id: netxray.h,v 1.4 2000/01/22 06:22:41 guy Exp $
+ * $Id: netxray.h,v 1.5 2000/08/11 13:32:34 deniel Exp $
  *
  * Wiretap Library
  * Copyright (c) 1998 by Gilbert Ramirez <gram@xiexie.org>
@@ -21,6 +21,11 @@
  *
  */
 
+#ifndef __NETXRAY_H__
+#define __NETXRAY_H__
+
 int netxray_open(wtap *wth, int *err);
 gboolean netxray_dump_open_1_1(wtap_dumper *wdh, int *err);
 int netxray_dump_can_write_encap(int filetype, int encap);
+
+#endif
